"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TelemetryHelper = void 0;
var _TelemetryConstants = require("./TelemetryConstants");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _TelemetryManager = require("./TelemetryManager");
var _utils = require("../utils");
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
let TelemetryHelper = /*#__PURE__*/function () {
  function TelemetryHelper() {
    _classCallCheck(this, TelemetryHelper);
  }
  _createClass(TelemetryHelper, null, [{
    key: "buildTelemetryEvent",
    value: function buildTelemetryEvent(level, input) {
      switch (input.scenarioType) {
        case _TelemetryConstants.ScenarioType.LOAD:
          return TelemetryHelper.conformToLoadContract(level, input);
        case _TelemetryConstants.ScenarioType.IC3_CLIENT:
          return TelemetryHelper.conformToIC3ClientContract(level, input);
        case _TelemetryConstants.ScenarioType.WEBCHAT:
          return TelemetryHelper.conformToWebChatContract(level, input);
        case _TelemetryConstants.ScenarioType.OCCHATSDK:
        case _TelemetryConstants.ScenarioType.SDK:
          return TelemetryHelper.conformToOCChatSDKContract(level, input);
        case _TelemetryConstants.ScenarioType.ACTIONS:
          return TelemetryHelper.conformToActionsContract(level, input);
        case _TelemetryConstants.ScenarioType.CALLING:
          return TelemetryHelper.conformToCallingContract(level, input);
        case _TelemetryConstants.ScenarioType.ACS_ADAPTER:
          return TelemetryHelper.conformToACSAdapterContract(level, input);
        default:
        case _TelemetryConstants.ScenarioType.CONFIG_VALIDATION:
          return TelemetryHelper.conformToConfigValidationContract(level, input);
      }
    }
  }, {
    key: "populateBasicProperties",
    value: function populateBasicProperties(level,
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    telemetryData) {
      var _TelemetryManager$Int, _TelemetryManager$Int2, _TelemetryManager$Int3, _TelemetryManager$Int4, _TelemetryManager$Int5, _TelemetryManager$Int6, _TelemetryManager$Int7, _TelemetryManager$Int8, _TelemetryManager$Int9, _TelemetryManager$Int10, _TelemetryManager$Int11;
      return {
        WidgetId: ((_TelemetryManager$Int = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int === void 0 ? void 0 : _TelemetryManager$Int.widgetId) ?? "",
        ChatId: ((_TelemetryManager$Int2 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int2 === void 0 ? void 0 : _TelemetryManager$Int2.chatId) ?? "",
        ChannelId: ((_TelemetryManager$Int3 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int3 === void 0 ? void 0 : _TelemetryManager$Int3.channelId) ?? "lcw2.0",
        ConversationId: ((_TelemetryManager$Int4 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int4 === void 0 ? void 0 : _TelemetryManager$Int4.conversationId) ?? "",
        OrganizationId: ((_TelemetryManager$Int5 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int5 === void 0 ? void 0 : _TelemetryManager$Int5.orgId) ?? "",
        OrganizationUrl: ((_TelemetryManager$Int6 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int6 === void 0 ? void 0 : _TelemetryManager$Int6.orgUrl) ?? "",
        LCWRuntimeId: ((_TelemetryManager$Int7 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int7 === void 0 ? void 0 : _TelemetryManager$Int7.lcwRuntimeId) ?? "",
        CurrentRequestId: ((_TelemetryManager$Int8 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int8 === void 0 ? void 0 : _TelemetryManager$Int8.currentRequestId) ?? "",
        LogLevel: level,
        OCChatSDKVersion: ((_TelemetryManager$Int9 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int9 === void 0 ? void 0 : _TelemetryManager$Int9.OCChatSDKVersion) ?? "",
        OCChatWidgetVersion: ((_TelemetryManager$Int10 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int10 === void 0 ? void 0 : _TelemetryManager$Int10.chatWidgetVersion) ?? "",
        OCChatComponentsVersion: ((_TelemetryManager$Int11 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int11 === void 0 ? void 0 : _TelemetryManager$Int11.chatComponentVersion) ?? ""
      };
    }
  }, {
    key: "populate",
    value: function populate(level, telemetryData, configure) {
      const base = TelemetryHelper.populateBasicProperties(level, telemetryData);
      const event = base;
      configure(event);
      return event;
    }
  }, {
    key: "conformToActionsContract",
    value: function conformToActionsContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.Event = payload.Event;
        event.ActionType = payload.ActionType;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
        event.Description = payload.Description;
        event.CustomProperties = JSON.stringify(payload.CustomProperties);
      });
    }
  }, {
    key: "conformToWebChatContract",
    value: function conformToWebChatContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.Event = payload.type;
        event.EventInfo = payload.name;
        event.Dimensions = payload.dimensions;
        event.Data = payload.data;
        event.Duration = payload.duration;
        event.ExceptionDetails = JSON.stringify(payload.error);
      });
    }
  }, {
    key: "conformToConfigValidationContract",
    value: function conformToConfigValidationContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        var _TelemetryManager$Int12, _TelemetryManager$Int13, _TelemetryManager$Int14;
        event.Event = payload.Event;
        event.RequestId = payload.RequestId;
        event.LCWVersion = (_TelemetryManager$Int12 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int12 === void 0 ? void 0 : _TelemetryManager$Int12.environmentVersion;
        event.CloudType = payload.CloudType;
        event.Domain = (_TelemetryManager$Int13 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int13 === void 0 ? void 0 : _TelemetryManager$Int13.hostName;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
        event.Language = ((_TelemetryManager$Int14 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int14 === void 0 ? void 0 : _TelemetryManager$Int14.chatWidgetLocaleLCID) || "";
        event.Description = payload.Data;
      });
    }
  }, {
    key: "conformToLoadContract",
    value: function conformToLoadContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.Event = payload.Event;
        event.Description = payload.Description;
        event.ResourcePath = payload.ResourcePath;
        event.WidgetState = payload.WidgetState;
        event.ChatState = payload.ChatState;
        event.ChatType = payload.ChatType;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
      });
    }
  }, {
    key: "conformToIC3ClientContract",
    value: function conformToIC3ClientContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        var _TelemetryManager$Int15;
        event.Event = payload.Event;
        event.IC3ClientVersion = (_TelemetryManager$Int15 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int15 === void 0 ? void 0 : _TelemetryManager$Int15.IC3ClientVersion;
        event.SubscriptionId = payload.SubscriptionId;
        event.EndpointUrl = payload.EndpointUrl;
        event.EndpointId = payload.EndpointId;
        event.ErrorCode = payload.ErrorCode;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
        event.ShouldBubbleToHost = payload.ShouldBubbleToHost;
        event.Description = payload.Description;
      });
    }
  }, {
    key: "conformToACSAdapterContract",
    value: function conformToACSAdapterContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.Description = payload.Description;
        event.ACSUserId = payload.ACSUserId;
        event.ChatThreadId = payload.ChatThreadId;
        event.ChatMessageId = payload.ChatMessageId;
        event.TimeStamp = payload.TimeStamp;
        event.Event = payload.Event;
        event.ErrorCode = payload.ErrorCode;
        event.ExceptionDetails = payload.ExceptionDetails;
      });
    }
  }, {
    key: "conformToCallingContract",
    value: function conformToCallingContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.CallId = payload.CallId;
        event.Event = payload.Event;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
        event.Description = payload.Description;
      });
    }
  }, {
    key: "conformToOCChatSDKContract",
    value: function conformToOCChatSDKContract(level, input) {
      const payload = input.payload;
      return TelemetryHelper.populate(level, payload, event => {
        event.RequestId = payload.RequestId;
        event.Event = payload.Event;
        event.OCChatSDKVersion = _TelemetryManager.TelemetryManager.InternalTelemetryData.OCChatSDKVersion ?? "";
        event.TransactionId = payload.TransactionId;
        event.ElapsedTimeInMilliseconds = payload.ElapsedTimeInMilliseconds;
        event.ExceptionDetails = JSON.stringify(payload.ExceptionDetails);
        event.Description = payload.Description;
      });
    }
  }, {
    key: "addChatConfigDataToTelemetry",
    value: function addChatConfigDataToTelemetry(chatConfig, telemetryInternalData) {
      var _chatConfig$ChatWidge;
      const telemetryDataLocal = telemetryInternalData;
      telemetryDataLocal.chatWidgetLocaleLCID = (_chatConfig$ChatWidge = chatConfig.ChatWidgetLanguage) === null || _chatConfig$ChatWidge === void 0 ? void 0 : _chatConfig$ChatWidge.msdyn_localeid;
      return telemetryDataLocal;
    }
  }, {
    key: "addWidgetDataToTelemetry",
    value: function addWidgetDataToTelemetry(telemetryConfig, telemetryInternalData) {
      const telemetryDataLocal = telemetryInternalData;
      if (!(telemetryConfig !== null && telemetryConfig !== void 0 && telemetryConfig.appId) || (telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.appId.trim()) === "") {
        throw new Error("TelemetryConfig.appId is not set");
      }
      if (!(telemetryConfig !== null && telemetryConfig !== void 0 && telemetryConfig.orgId) || (telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.orgId.trim()) === "") {
        throw new Error("TelemetryConfig.orgId is not set");
      }
      if (!(telemetryConfig !== null && telemetryConfig !== void 0 && telemetryConfig.orgUrl) || (telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.orgUrl.trim()) === "") {
        throw new Error("TelemetryConfig.orgUrl is not set");
      }
      telemetryDataLocal.widgetId = telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.appId;
      telemetryDataLocal.orgId = telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.orgId;
      telemetryDataLocal.orgUrl = telemetryConfig === null || telemetryConfig === void 0 ? void 0 : telemetryConfig.orgUrl;
      telemetryDataLocal.lcwRuntimeId = telemetryConfig.LCWRuntimeId ?? (0, _utils.newGuid)();
      return telemetryDataLocal;
    }
  }, {
    key: "addSessionDataToTelemetry",
    value: function addSessionDataToTelemetry(chatSession, telemetryInternalData) {
      var _chatSession$chatToke, _chatSession$chatToke2;
      const telemetryDataLocal = telemetryInternalData;
      telemetryDataLocal.chatId = chatSession === null || chatSession === void 0 ? void 0 : (_chatSession$chatToke = chatSession.chatToken) === null || _chatSession$chatToke === void 0 ? void 0 : _chatSession$chatToke.chatId;
      telemetryDataLocal.currentRequestId = chatSession === null || chatSession === void 0 ? void 0 : (_chatSession$chatToke2 = chatSession.chatToken) === null || _chatSession$chatToke2 === void 0 ? void 0 : _chatSession$chatToke2.requestId;
      return telemetryInternalData;
    }
  }, {
    key: "addConversationDataToTelemetry",
    value: function addConversationDataToTelemetry(liveWorkItem, telemetryInternalData) {
      const telemetryDataLocal = telemetryInternalData;
      telemetryDataLocal.conversationId = liveWorkItem.conversationId;
      return telemetryDataLocal;
    }

    // eslint-disable-next-line @typescript-eslint/no-explicit-any
  }, {
    key: "postTelemetryEvent",
    value: function postTelemetryEvent(eventName, logLevel, payload) {
      const telemetryEvent = {
        eventName,
        logLevel,
        payload: {
          ...payload
        }
      };
      _omnichannelChatComponents.BroadcastService.postMessage(telemetryEvent);
    }
  }]);
  return TelemetryHelper;
}();
exports.TelemetryHelper = TelemetryHelper;
_defineProperty(TelemetryHelper, "callId", void 0);
_defineProperty(TelemetryHelper, "elapsedTime", void 0);
_defineProperty(TelemetryHelper, "logCallingEvent", (logLevel, payload, callId) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, {
    ...payload,
    CallId: callId
  });
});
_defineProperty(TelemetryHelper, "logLoadingEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, payload);
});
_defineProperty(TelemetryHelper, "logUIEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, payload);
});
_defineProperty(TelemetryHelper, "logActionEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, payload);
});
_defineProperty(TelemetryHelper, "logSDKEvent", (logLevel, payload) => {
  var _TelemetryManager$Int16;
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, {
    ...payload,
    TransactionId: (0, _utils.newGuid)(),
    RequestId: (_TelemetryManager$Int16 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int16 === void 0 ? void 0 : _TelemetryManager$Int16.currentRequestId
  });
});
_defineProperty(TelemetryHelper, "logConfigDataEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, payload);
});
_defineProperty(TelemetryHelper, "logWebChatEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent(_TelemetryConstants.TelemetryEvent.WebChatEvent, logLevel, {
    ...payload,
    type: _TelemetryConstants.TelemetryEvent.WebChatEvent,
    scenarioType: _TelemetryConstants.ScenarioType.WEBCHAT
  });
});
_defineProperty(TelemetryHelper, "logFacadeChatSDKEvent", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? _TelemetryConstants.TelemetryEvent.FacadeChatSDKEvent, logLevel, payload);
});
_defineProperty(TelemetryHelper, "logLoadingEventToAllTelemetry", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, {
    ...payload,
    LogToAll: true
  });
});
_defineProperty(TelemetryHelper, "logActionEventToAllTelemetry", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, {
    ...payload,
    LogToAll: true
  });
});
_defineProperty(TelemetryHelper, "logFacadeChatSDKEventToAllTelemetry", (logLevel, payload) => {
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? _TelemetryConstants.TelemetryEvent.FacadeChatSDKEvent, logLevel, {
    ...payload,
    LogToAll: true
  });
});
_defineProperty(TelemetryHelper, "logSDKEventToAllTelemetry", (logLevel, payload) => {
  var _TelemetryManager$Int17;
  TelemetryHelper.postTelemetryEvent((payload === null || payload === void 0 ? void 0 : payload.Event) ?? "", logLevel, {
    ...{
      ...payload,
      TransactionId: (0, _utils.newGuid)(),
      RequestId: (_TelemetryManager$Int17 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int17 === void 0 ? void 0 : _TelemetryManager$Int17.currentRequestId
    },
    LogToAll: true
  });
});