"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.EmailTranscriptPaneStateful = void 0;
var _TelemetryConstants = require("../../common/telemetry/TelemetryConstants");
var _react = _interopRequireWildcard(require("react"));
var _utils = require("../../common/utils");
var _DimLayer = require("../dimlayer/DimLayer");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _LiveChatWidgetActionType = require("../../contexts/common/LiveChatWidgetActionType");
var _NotificationHandler = require("../webchatcontainerstateful/webchatcontroller/notification/NotificationHandler");
var _NotificationScenarios = require("../webchatcontainerstateful/webchatcontroller/enums/NotificationScenarios");
var _Constants = require("../../common/Constants");
var _TelemetryHelper = require("../../common/telemetry/TelemetryHelper");
var _defaultMiddlewareLocalizedTexts = require("../webchatcontainerstateful/common/defaultProps/defaultMiddlewareLocalizedTexts");
var _useChatContextStore = _interopRequireDefault(require("../../hooks/useChatContextStore"));
var _useFacadeChatSDKStore = _interopRequireDefault(require("../../hooks/useFacadeChatSDKStore"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
let uiTimer;
const EmailTranscriptPaneStateful = props => {
  var _props$controlProps;
  // this is to ensure the telemetry is set only once and start the load timer
  (0, _react.useEffect)(() => {
    uiTimer = (0, _utils.createTimer)();
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXEmailTranscriptPaneStart
    });
  }, []);
  const initialTabIndexMap = new Map();
  let elements = [];
  const [state, dispatch] = (0, _useChatContextStore.default)();
  const [facadeChatSDK] = (0, _useFacadeChatSDKStore.default)();
  const [initialEmail, setInitialEmail] = (0, _react.useState)("");
  const closeEmailTranscriptPane = () => {
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_SHOW_EMAIL_TRANSCRIPT_PANE,
      payload: false
    });
    const previousFocusedElementId = state.appStates.previousElementIdOnFocusBeforeModalOpen;
    if (previousFocusedElementId) {
      (0, _utils.setFocusOnElement)("#" + previousFocusedElementId);
    } else {
      (0, _utils.setFocusOnSendBox)();
    }
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_PREVIOUS_FOCUSED_ELEMENT_ID,
      payload: null
    });
    (0, _utils.setTabIndices)(elements, initialTabIndexMap, true);
  };
  const onSend = (0, _react.useCallback)(async email => {
    var _state$domainStates;
    const liveChatContext = state === null || state === void 0 ? void 0 : (_state$domainStates = state.domainStates) === null || _state$domainStates === void 0 ? void 0 : _state$domainStates.liveChatContext;
    closeEmailTranscriptPane();
    const chatTranscriptBody = {
      emailAddress: email,
      attachmentMessage: (props === null || props === void 0 ? void 0 : props.attachmentMessage) ?? "The following attachment was uploaded during the conversation:"
    };
    try {
      var _state$domainStates2, _state$domainStates2$;
      await (facadeChatSDK === null || facadeChatSDK === void 0 ? void 0 : facadeChatSDK.emailLiveChatTranscript(chatTranscriptBody, {
        liveChatContext
      }));
      _NotificationHandler.NotificationHandler.notifySuccess(_NotificationScenarios.NotificationScenarios.EmailAddressSaved, (state === null || state === void 0 ? void 0 : (_state$domainStates2 = state.domainStates) === null || _state$domainStates2 === void 0 ? void 0 : (_state$domainStates2$ = _state$domainStates2.middlewareLocalizedTexts) === null || _state$domainStates2$ === void 0 ? void 0 : _state$domainStates2$.MIDDLEWARE_BANNER_FILE_EMAIL_ADDRESS_RECORDED_SUCCESS) ?? (_defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts === null || _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts === void 0 ? void 0 : _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_FILE_EMAIL_ADDRESS_RECORDED_SUCCESS));
      _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.EmailTranscriptSent,
        Description: "Transcript sent to email successfully."
      });
    } catch (ex) {
      var _state$domainStates3, _state$domainStates3$;
      _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.EmailTranscriptFailed,
        Description: "Email transcript failed.",
        ExceptionDetails: {
          exception: ex
        }
      });
      const message = (0, _utils.formatTemplateString)((state === null || state === void 0 ? void 0 : (_state$domainStates3 = state.domainStates) === null || _state$domainStates3 === void 0 ? void 0 : (_state$domainStates3$ = _state$domainStates3.middlewareLocalizedTexts) === null || _state$domainStates3$ === void 0 ? void 0 : _state$domainStates3$.MIDDLEWARE_BANNER_FILE_EMAIL_ADDRESS_RECORDED_ERROR) ?? _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_FILE_EMAIL_ADDRESS_RECORDED_ERROR, [email]);
      _NotificationHandler.NotificationHandler.notifyError(_NotificationScenarios.NotificationScenarios.EmailTranscriptError, (props === null || props === void 0 ? void 0 : props.bannerMessageOnError) ?? message);
    }
  }, [props.attachmentMessage, props.bannerMessageOnError, facadeChatSDK, state.domainStates.liveChatContext]);
  const controlProps = {
    id: "oclcw-emailTranscriptDialogContainer",
    dir: state.domainStates.globalDir,
    onSend,
    onCancel: () => {
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.EmailTranscriptCancelButtonClicked,
        Description: "Email Transcript cancel button clicked."
      });
      closeEmailTranscriptPane();
    },
    checkInput: function (input) {
      return new RegExp(_Constants.Regex.EmailRegex).test(input);
    },
    ...props.controlProps,
    inputInitialText: ((_props$controlProps = props.controlProps) === null || _props$controlProps === void 0 ? void 0 : _props$controlProps.inputInitialText) ?? initialEmail
  };

  // Move focus to the first button
  (0, _react.useEffect)(() => {
    (0, _utils.preventFocusToMoveOutOfElement)(controlProps.id);
    const focusableElements = (0, _utils.findAllFocusableElement)(`#${controlProps.id}`);
    if (focusableElements) {
      focusableElements[0].focus();
    }
    elements = (0, _utils.findParentFocusableElementsWithoutChildContainer)(controlProps.id);
    (0, _utils.setTabIndices)(elements, initialTabIndexMap, false);
    setInitialEmail(state.appStates.preChatResponseEmail);
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.EmailTranscriptLoaded
    });
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXEmailTranscriptPaneCompleted,
      ElapsedTimeInMilliseconds: uiTimer.milliSecondsElapsed
    });
  }, [initialEmail]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_DimLayer.DimLayer, {
    brightness: (controlProps === null || controlProps === void 0 ? void 0 : controlProps.brightnessValueOnDim) ?? "0.2"
  }), /*#__PURE__*/_react.default.createElement(_omnichannelChatComponents.InputValidationPane, {
    componentOverrides: props.componentOverrides,
    controlProps: controlProps,
    styleProps: props.styleProps
  }));
};
exports.EmailTranscriptPaneStateful = EmailTranscriptPaneStateful;
var _default = EmailTranscriptPaneStateful;
exports.default = _default;