"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.LiveChatWidget = void 0;
var _react = _interopRequireWildcard(require("react"));
var _ChatAdapterStore = require("../../contexts/ChatAdapterStore");
var _ChatContextStore = require("../../contexts/ChatContextStore");
var _ChatSDKStore = require("../../contexts/ChatSDKStore");
var _ErrorBoundary = _interopRequireDefault(require("../errorboundary/ErrorBoundary"));
var _FacadeChatSDK = require("../../common/facades/FacadeChatSDK");
var _FacadeChatSDKStore = require("../../contexts/FacadeChatSDKStore");
var _LiveChatWidgetStateful = _interopRequireDefault(require("./livechatwidgetstateful/LiveChatWidgetStateful"));
var _createReducer = require("../../contexts/createReducer");
var _LiveChatWidgetContextInitialState = require("../../contexts/common/LiveChatWidgetContextInitialState");
var _getMockChatSDKIfApplicable = require("./common/getMockChatSDKIfApplicable");
var _utils = require("../../common/utils");
var _overridePropsOnMockIfApplicable = _interopRequireDefault(require("./common/overridePropsOnMockIfApplicable"));
var _registerTelemetryLoggers = require("./common/registerTelemetryLoggers");
var _startChatErrorHandler = require("./common/startChatErrorHandler");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const LiveChatWidget = props => {
  var _props$mock, _props$featureConfigP, _props$chatConfig, _props$chatConfig$Liv;
  const reducer = (0, _createReducer.createReducer)();
  const [state, dispatch] = (0, _react.useReducer)(reducer, (0, _LiveChatWidgetContextInitialState.getLiveChatWidgetContextInitialState)(props));
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const [adapter, setAdapter] = (0, _react.useState)(undefined);
  const [facadeChatSDK, setFacadeChatSDK] = (0, _react.useState)(undefined);
  const chatSDK = (0, _getMockChatSDKIfApplicable.getMockChatSDKIfApplicable)(props.chatSDK, props === null || props === void 0 ? void 0 : (_props$mock = props.mock) === null || _props$mock === void 0 ? void 0 : _props$mock.type);
  const disableReauthentication = ((_props$featureConfigP = props.featureConfigProps) === null || _props$featureConfigP === void 0 ? void 0 : _props$featureConfigP.disableReauthentication) === true;
  (0, _overridePropsOnMockIfApplicable.default)(props);
  if (!props.chatConfig) {
    throw new Error("chatConfig is required");
  }

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const isAuthenticatedChat = !!((_props$chatConfig = props.chatConfig) !== null && _props$chatConfig !== void 0 && (_props$chatConfig$Liv = _props$chatConfig.LiveChatConfigAuthSettings) !== null && _props$chatConfig$Liv !== void 0 && _props$chatConfig$Liv.msdyn_javascriptclientfunction);
  if (!facadeChatSDK) {
    var _props$mock2;
    setFacadeChatSDK(new _FacadeChatSDK.FacadeChatSDK({
      "chatSDK": chatSDK,
      "chatConfig": props.chatConfig,
      "isAuthenticated": isAuthenticatedChat,
      "getAuthToken": props === null || props === void 0 ? void 0 : props.getAuthToken,
      //when type is not undefined, it means the SDK is mocked
      "isSDKMocked": !(0, _utils.isNullOrUndefined)(props === null || props === void 0 ? void 0 : (_props$mock2 = props.mock) === null || _props$mock2 === void 0 ? void 0 : _props$mock2.type)
    }, disableReauthentication));
  }
  (0, _react.useEffect)(() => {
    (0, _registerTelemetryLoggers.registerTelemetryLoggers)(props, dispatch);
  }, [dispatch]);
  return /*#__PURE__*/_react.default.createElement(_ErrorBoundary.default, {
    onError: error => {
      (0, _startChatErrorHandler.logWidgetLoadWithUnexpectedError)(error);
    }
  }, /*#__PURE__*/_react.default.createElement(_FacadeChatSDKStore.FacadeChatSDKStore.Provider, {
    value: [facadeChatSDK, setFacadeChatSDK]
  }, /*#__PURE__*/_react.default.createElement(_ChatSDKStore.ChatSDKStore.Provider, {
    value: chatSDK
  }, /*#__PURE__*/_react.default.createElement(_ChatAdapterStore.ChatAdapterStore.Provider, {
    value: [adapter, setAdapter]
  }, /*#__PURE__*/_react.default.createElement(_ChatContextStore.ChatContextStore.Provider, {
    value: [state, dispatch]
  }, /*#__PURE__*/_react.default.createElement(_LiveChatWidgetStateful.default, props))))));
};
exports.LiveChatWidget = LiveChatWidget;
var _default = LiveChatWidget;
exports.default = _default;