"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeAuthTokenProvider = exports.handleAuthentication = exports.getAuthClientFunction = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _Constants = require("../../../common/Constants");
var _utils = require("../../../common/utils");
const getAuthClientFunction = chatConfig => {
  let authClientFunction = undefined;
  if (chatConfig !== null && chatConfig !== void 0 && chatConfig.LiveChatConfigAuthSettings) {
    var _chatConfig$LiveChatC;
    authClientFunction = (chatConfig === null || chatConfig === void 0 ? void 0 : (_chatConfig$LiveChatC = chatConfig.LiveChatConfigAuthSettings) === null || _chatConfig$LiveChatC === void 0 ? void 0 : _chatConfig$LiveChatC.msdyn_javascriptclientfunction) ?? undefined;
  }
  return authClientFunction;
};
exports.getAuthClientFunction = getAuthClientFunction;
const handleAuthentication = async (chatSDK, chatConfig, getAuthToken) => {
  var _chatSDK$chatSDKConfi;
  const authClientFunction = getAuthClientFunction(chatConfig);
  if (getAuthToken && authClientFunction) {
    _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.GetAuthTokenCalled
    });
    const token = await getAuthToken(authClientFunction);
    if (!(0, _utils.isNullOrEmptyString)(token)) {
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      chatSDK.setAuthTokenProvider(async () => {
        return token;
      });
      return {
        "result": true,
        "token": token
      };
    } else {
      // instead of returning false, it's more appropiate to thrown an error to force error handling on the caller side
      // this will help to avoid the error to be ignored and the chat to be started
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.ReceivedNullOrEmptyToken
      });
      throw new Error(_Constants.WidgetLoadCustomErrorString.AuthenticationFailedErrorString);
    }
  } else if (chatSDK !== null && chatSDK !== void 0 && (_chatSDK$chatSDKConfi = chatSDK.chatSDKConfig) !== null && _chatSDK$chatSDKConfi !== void 0 && _chatSDK$chatSDKConfi.getAuthToken) {
    var _chatSDK$chatSDKConfi2;
    const token = await ((_chatSDK$chatSDKConfi2 = chatSDK.chatSDKConfig) === null || _chatSDK$chatSDKConfi2 === void 0 ? void 0 : _chatSDK$chatSDKConfi2.getAuthToken());
    if ((0, _utils.isNullOrEmptyString)(token)) {
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.ReceivedNullOrEmptyToken,
        Description: "getAuthToken in chat SDK returns empty string"
      });
      throw new Error(_Constants.WidgetLoadCustomErrorString.AuthenticationFailedErrorString);
    }
    return {
      "result": true,
      token
    };
  }
  return {
    "result": false,
    "token": null,
    "error": {
      "message": "No auth client function or getAuthToken function provided",
      "getAuthTokenPresent": getAuthToken ? true : false,
      "authClientFunctionPresent": authClientFunction ? true : false
    }
  };
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.handleAuthentication = handleAuthentication;
const removeAuthTokenProvider = chatSDK => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.authenticatedUserToken = null;
};
exports.removeAuthTokenProvider = removeAuthTokenProvider;