"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAdapter = void 0;
var _BotAuthActivitySubscriber = require("./ActivitySubscriber/BotAuthActivitySubscriber");
var _ChatAdapterShim = require("./ChatAdapterShim");
var _HiddenAdaptiveCardActivitySubscriber = require("./ActivitySubscriber/HiddenAdaptiveCardActivitySubscriber");
var _mockchatsdk = require("../../webchatcontainerstateful/common/mockchatsdk");
var _NotificationHandler = require("../../webchatcontainerstateful/webchatcontroller/notification/NotificationHandler");
var _NotificationLevel = require("../../webchatcontainerstateful/webchatcontroller/enums/NotificationLevel");
var _NotificationScenarios = require("../../webchatcontainerstateful/webchatcontroller/enums/NotificationScenarios");
var _PauseActivitySubscriber = require("./ActivitySubscriber/PauseActivitySubscriber");
var _defaultMiddlewareLocalizedTexts = require("../../webchatcontainerstateful/common/defaultProps/defaultMiddlewareLocalizedTexts");
const defaultBotAuthConfig = {
  fetchBotAuthConfigRetries: 3,
  fetchBotAuthConfigRetryInterval: 1000
};
const createAdapter = async (facadeChatSDK, props) => {
  const chatAdapterOptionalParams = {
    IC3Adapter: {
      options: {
        callbackOnNotification: notification => {
          if (notification.id === _NotificationScenarios.NotificationScenarios.InternetConnection && notification.level == _NotificationLevel.NotificationLevel.Error) {
            notification.message = _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_NO_INTERNET_CONNECTION;
          }
          if (notification.id === _NotificationScenarios.NotificationScenarios.InternetConnection && notification.level == _NotificationLevel.NotificationLevel.Success) {
            notification.message = _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_INTERNET_BACK_ONLINE;
          }
          if (notification.id && notification.message) {
            _NotificationHandler.NotificationHandler.notifyWithLevel(notification.id, notification.message, notification.level);
          }
        }
      }
    },
    ACSAdapter: {
      fileScan: {
        disabled: false
      }
    }
  };
  let adapter = await facadeChatSDK.createChatAdapter(chatAdapterOptionalParams);
  //so far, there is no need to convert to the shim adapter when using visual tests
  const isMocked = facadeChatSDK.getChatSDK() instanceof _mockchatsdk.MockChatSDK;
  if (isMocked !== true) {
    var _props$webChatContain, _props$webChatContain2, _props$webChatContain3, _props$webChatContain4;
    const botAuthActivitySubscriberOptionalParams = {
      fetchBotAuthConfigRetries: (props === null || props === void 0 ? void 0 : (_props$webChatContain = props.webChatContainerProps) === null || _props$webChatContain === void 0 ? void 0 : (_props$webChatContain2 = _props$webChatContain.botAuthConfig) === null || _props$webChatContain2 === void 0 ? void 0 : _props$webChatContain2.fetchBotAuthConfigRetries) || defaultBotAuthConfig.fetchBotAuthConfigRetries,
      fetchBotAuthConfigRetryInterval: (props === null || props === void 0 ? void 0 : (_props$webChatContain3 = props.webChatContainerProps) === null || _props$webChatContain3 === void 0 ? void 0 : (_props$webChatContain4 = _props$webChatContain3.botAuthConfig) === null || _props$webChatContain4 === void 0 ? void 0 : _props$webChatContain4.fetchBotAuthConfigRetryInterval) || defaultBotAuthConfig.fetchBotAuthConfigRetryInterval
    };
    adapter = new _ChatAdapterShim.ChatAdapterShim(adapter);
    adapter.addSubscriber(new _PauseActivitySubscriber.PauseActivitySubscriber());
    adapter.addSubscriber(new _BotAuthActivitySubscriber.BotAuthActivitySubscriber(botAuthActivitySubscriberOptionalParams));
    // Remove this code after ICM ID:544623085 is fixed
    adapter.addSubscriber(new _HiddenAdaptiveCardActivitySubscriber.HiddenAdaptiveCardActivitySubscriber());
    return adapter.chatAdapter;
  }
  return adapter;
};
exports.createAdapter = createAdapter;