"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createInternetConnectionChangeHandler = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _Constants = require("../../../common/Constants");
var _NotificationHandler = require("../../webchatcontainerstateful/webchatcontroller/notification/NotificationHandler");
var _NotificationScenarios = require("../../webchatcontainerstateful/webchatcontroller/enums/NotificationScenarios");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _defaultMiddlewareLocalizedTexts = require("../../webchatcontainerstateful/common/defaultProps/defaultMiddlewareLocalizedTexts");
var _createReducer = require("../../../contexts/createReducer");
var _LiveChatWidgetActionType = require("../../../contexts/common/LiveChatWidgetActionType");
const isInternetConnected = async () => {
  try {
    const response = await fetch(_Constants.Constants.internetConnectionTestUrl);
    const text = await response.text();
    return text === _Constants.Constants.internetConnectionTestUrlText;
  } catch {
    return false;
  }
};
const createInternetConnectionChangeHandler = async state => {
  const handler = async () => {
    const connected = await isInternetConnected();
    const inMemoryState = (0, _createReducer.executeReducer)(state, {
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: null
    });
    if (!connected) {
      var _inMemoryState$domain, _inMemoryState$domain2;
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.WARN, {
        Event: _TelemetryConstants.TelemetryEvent.NetworkDisconnected
      });
      _NotificationHandler.NotificationHandler.notifyError(_NotificationScenarios.NotificationScenarios.InternetConnection, (inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$domain = inMemoryState.domainStates) === null || _inMemoryState$domain === void 0 ? void 0 : (_inMemoryState$domain2 = _inMemoryState$domain.middlewareLocalizedTexts) === null || _inMemoryState$domain2 === void 0 ? void 0 : _inMemoryState$domain2.MIDDLEWARE_BANNER_NO_INTERNET_CONNECTION) ?? _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_NO_INTERNET_CONNECTION);
    } else {
      var _inMemoryState$domain3, _inMemoryState$domain4;
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.WARN, {
        Event: _TelemetryConstants.TelemetryEvent.NetworkReconnected
      });
      _NotificationHandler.NotificationHandler.notifySuccess(_NotificationScenarios.NotificationScenarios.InternetConnection, (inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$domain3 = inMemoryState.domainStates) === null || _inMemoryState$domain3 === void 0 ? void 0 : (_inMemoryState$domain4 = _inMemoryState$domain3.middlewareLocalizedTexts) === null || _inMemoryState$domain4 === void 0 ? void 0 : _inMemoryState$domain4.MIDDLEWARE_BANNER_INTERNET_BACK_ONLINE) ?? _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_INTERNET_BACK_ONLINE);
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.NetworkReconnected
      });
    }
  };

  // Checking connection status on online & offline events due to possible false positives
  window.addEventListener("online", () => handler(), false);
  window.addEventListener("offline", () => handler(), false);
};
exports.createInternetConnectionChangeHandler = createInternetConnectionChangeHandler;