"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareEndChat = exports.endVoiceVideoCallIfOngoing = exports.endChatStateCleanUp = exports.endChat = exports.closeChatStateCleanUp = exports.chatSDKStateCleanUp = exports.callingStateCleanUp = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _Constants = require("../../../common/Constants");
var _utils = require("../../../common/utils");
var _renderSurveyHelpers = require("./renderSurveyHelpers");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _ConversationState = require("../../../contexts/common/ConversationState");
var _LiveChatWidgetActionType = require("../../../contexts/common/LiveChatWidgetActionType");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _TelemetryManager = require("../../../common/telemetry/TelemetryManager");
var _WebChatStoreLoader = require("../../webchatcontainerstateful/webchatcontroller/WebChatStoreLoader");
var _defaultWebChatContainerStatefulProps = require("../../webchatcontainerstateful/common/defaultProps/defaultWebChatContainerStatefulProps");
var _createReducer = require("../../../contexts/createReducer");
var _reconnectChatHelper = require("./reconnectChatHelper");
var _omnichannelChatSdk = require("@microsoft/omnichannel-chat-sdk");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const prepareEndChat = async (props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter) => {
  try {
    var _conversationDetails$, _state$domainStates, _state$appStates3;
    const {
      chatConfig
    } = props;

    // Use Case: If call is ongoing, end the call by simulating end call button click
    endVoiceVideoCallIfOngoing(facadeChatSDK, dispatch);
    const conversationDetails = await (0, _utils.getConversationDetailsCall)(facadeChatSDK);

    // Use Case: When post chat is not configured
    if ((conversationDetails === null || conversationDetails === void 0 ? void 0 : (_conversationDetails$ = conversationDetails.canRenderPostChat) === null || _conversationDetails$ === void 0 ? void 0 : _conversationDetails$.toLowerCase()) === _Constants.Constants.false) {
      var _state$appStates;
      // If ended by customer, just close chat
      if ((state === null || state === void 0 ? void 0 : (_state$appStates = state.appStates) === null || _state$appStates === void 0 ? void 0 : _state$appStates.conversationEndedBy) === _Constants.ConversationEndEntity.Customer) {
        _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.PrepareEndChat,
          Description: _Constants.PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithoutPostChat
        });
        await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
      }

      // Use Case: If ended by Agent, stay chat in InActive state
      return;
    }

    // Register post chat participant type
    if ((conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType) === _Constants.ParticipantType.Bot || (conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType) === _Constants.ParticipantType.User) {
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_POST_CHAT_PARTICIPANT_TYPE,
        payload: conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType
      });
    }

    // Use Case: Can render post chat scenarios
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const postchatContext = (await (0, _renderSurveyHelpers.getPostChatContext)(facadeChatSDK, state, dispatch)) ?? (state === null || state === void 0 ? void 0 : (_state$domainStates = state.domainStates) === null || _state$domainStates === void 0 ? void 0 : _state$domainStates.postChatContext);
    if (postchatContext === undefined) {
      var _state$appStates2;
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.OnWidgetError,
        payload: {
          errorMessage: "Widget did not display post chat survey as getPostChatContext returned undefined."
        }
      });

      // For Customer intiated conversations, just close chat widget
      if ((state === null || state === void 0 ? void 0 : (_state$appStates2 = state.appStates) === null || _state$appStates2 === void 0 ? void 0 : _state$appStates2.conversationEndedBy) === _Constants.ConversationEndEntity.Customer) {
        _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.PrepareEndChat,
          Description: _Constants.PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithInvalidPostChat
        });
        await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
        return;
      }

      //For agent initiated end chat, allow to download transcript
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
        payload: _ConversationState.ConversationState.InActive
      });
      return;
    }

    // Log PrepareEndChat if conversation ended by customer (bot and agent cases are handled in LiveChatWidgetStateful.tsx)
    if (state !== null && state !== void 0 && (_state$appStates3 = state.appStates) !== null && _state$appStates3 !== void 0 && _state$appStates3.conversationEndedBy) {
      var _state$appStates4;
      _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.PrepareEndChat,
        Description: `${_Constants.PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithInvalidPostChat} ${state === null || state === void 0 ? void 0 : (_state$appStates4 = state.appStates) === null || _state$appStates4 === void 0 ? void 0 : _state$appStates4.conversationEndedBy}.`
      });
    }
    const persistentEnabled = (0, _reconnectChatHelper.isPersistentEnabled)(chatConfig);
    const {
      appStates
    } = (0, _createReducer.executeReducer)(state, {
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: undefined
    });
    const endedByCustomer = (appStates === null || appStates === void 0 ? void 0 : appStates.conversationEndedBy) === "Customer";

    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const commonParams = [props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter];
    if (persistentEnabled && endedByCustomer) {
      await endChat(...commonParams, true, false, true);
    } else {
      await endChat(...commonParams, false, true, true);
      if (postchatContext) {
        await (0, _renderSurveyHelpers.initiatePostChat)(props, conversationDetails, state, dispatch, postchatContext);
        return;
      }
    }
  } catch (error) {
    var _props$controlProps;
    _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.ERROR, {
      Event: _TelemetryConstants.TelemetryEvent.EndChatFailed,
      ExceptionDetails: {
        exception: JSON.stringify(error)
      }
    });

    //Close chat widget for any failure in embedded to allow to show start chat button
    if (((_props$controlProps = props.controlProps) === null || _props$controlProps === void 0 ? void 0 : _props$controlProps.hideStartChatButton) === false) {
      _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.PrepareEndChat,
        Description: _Constants.PrepareEndChatDescriptionConstants.PrepareEndChatError
      });
      await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
    }
  } finally {
    //Chat token clean up
    await chatTokenCleanUp(dispatch);
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.prepareEndChat = prepareEndChat;
const endChat = async (props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, skipEndChatSDK, skipCloseChat, postMessageToOtherTab) => {
  var _facadeChatSDK$getCha;
  if (!skipEndChatSDK && facadeChatSDK !== null && facadeChatSDK !== void 0 && (_facadeChatSDK$getCha = facadeChatSDK.getChatSDK()) !== null && _facadeChatSDK$getCha !== void 0 && _facadeChatSDK$getCha.conversation) {
    var _inMemoryState$appSta;
    const inMemoryState = (0, _createReducer.executeReducer)(state, {
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: null
    });
    const endChatOptionalParameters = {
      isSessionEnded: inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$appSta = inMemoryState.appStates) === null || _inMemoryState$appSta === void 0 ? void 0 : _inMemoryState$appSta.chatDisconnectEventReceived
    };
    try {
      _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.EndChatSDKCall
      });
      await (facadeChatSDK === null || facadeChatSDK === void 0 ? void 0 : facadeChatSDK.endChat(endChatOptionalParameters));
    } catch (ex) {
      var _inMemoryState$appSta2;
      // if the chat was disconnected or ended by the agent, we don't want to log the error
      if (!(inMemoryState !== null && inMemoryState !== void 0 && (_inMemoryState$appSta2 = inMemoryState.appStates) !== null && _inMemoryState$appSta2 !== void 0 && _inMemoryState$appSta2.chatDisconnectEventReceived)) {
        _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.ERROR, {
          Event: _TelemetryConstants.TelemetryEvent.EndChatSDKCallFailed,
          ExceptionDetails: {
            exception: ex
          }
        });
      } else {
        _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.WARN, {
          Event: _TelemetryConstants.TelemetryEvent.DisconnectEndChatSDKCallFailed,
          ExceptionDetails: {
            exception: ex
          }
        });
      }
      postMessageToOtherTab = false;
    } finally {
      endChatStateCleanUp(dispatch);
      facadeChatSDK.destroy();
    }
  }
  if (!skipCloseChat) {
    try {
      var _props$webChatContain;
      adapter === null || adapter === void 0 ? void 0 : adapter.end();
      setAdapter(undefined);
      setWebChatStyles({
        ..._defaultWebChatContainerStatefulProps.defaultWebChatContainerStatefulProps.webChatStyles,
        ...((_props$webChatContain = props.webChatContainerProps) === null || _props$webChatContain === void 0 ? void 0 : _props$webChatContain.webChatStyles)
      });
      _WebChatStoreLoader.WebChatStoreLoader.store = null;
      closeChatStateCleanUp(dispatch);
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.CloseChatCall,
        Description: "Chat was closed succesfully"
      });
    } catch (error) {
      _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.CloseChatMethodException,
        ExceptionDetails: {
          exception: `Failed to endChat: ${error}`
        }
      });
    } finally {
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_UNREAD_MESSAGE_COUNT,
        payload: 0
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_POST_CHAT_CONTEXT,
        payload: undefined
      });
      // Always allow to close the chat for embedded mode irrespective of end chat errors
      closeChatWidget(dispatch);
      facadeChatSDK.destroy();
    }
  }
  if (postMessageToOtherTab) {
    const endChatEventName = await getEndChatEventName(facadeChatSDK, props);
    _omnichannelChatComponents.BroadcastService.postMessage({
      eventName: endChatEventName,
      payload: {
        runtimeId: _TelemetryManager.TelemetryManager.InternalTelemetryData.lcwRuntimeId
      }
    });
  }
};
exports.endChat = endChat;
const callingStateCleanUp = dispatch => {
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SHOW_CALLING_CONTAINER,
    payload: false
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_INCOMING_CALL,
    payload: true
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.DISABLE_VIDEO_CALL,
    payload: true
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.DISABLE_LOCAL_VIDEO,
    payload: true
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.DISABLE_REMOTE_VIDEO,
    payload: true
  });
};
exports.callingStateCleanUp = callingStateCleanUp;
const endChatStateCleanUp = dispatch => {
  // Need to clear these states immediately when chat ended from OC.
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_RECONNECT_ID,
    payload: undefined
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CHAT_DISCONNECT_EVENT_RECEIVED,
    payload: false
  });
};
exports.endChatStateCleanUp = endChatStateCleanUp;
const closeChatStateCleanUp = dispatch => {
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CHAT_TOKEN,
    payload: undefined
  });
  // dispatch({ type: LiveChatWidgetActionType.SET_CONVERSATION_STATE, payload: ConversationState.Closed });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_RECONNECT_ID,
    payload: undefined
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_AUDIO_NOTIFICATION,
    payload: null
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_ENDED_BY,
    payload: _Constants.ConversationEndEntity.NotSet
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONFIRMATION_STATE,
    payload: _Constants.ConfirmationState.NotSet
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_START_CHAT_FAILING,
    payload: false
  });
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_PROACTIVE_CHAT_PARAMS,
    payload: {
      proactiveChatBodyTitle: "",
      proactiveChatEnablePrechat: false,
      proactiveChatInNewWindow: false
    }
  });

  // Clear live chat context only if chat widget is fully closed to support transcript calls after sessionclose is called
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_LIVE_CHAT_CONTEXT,
    payload: undefined
  });
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.closeChatStateCleanUp = closeChatStateCleanUp;
const chatSDKStateCleanUp = chatSDK => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.requestId = (0, _omnichannelChatSdk.uuidv4)();
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.chatToken = {};
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.reconnectId = null;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.chatSDKStateCleanUp = chatSDKStateCleanUp;
const endVoiceVideoCallIfOngoing = async (facadeChatSDK, dispatch) => {
  let callId = "";
  try {
    if (facadeChatSDK.getChatSDK().isVoiceVideoCallingEnabled()) {
      const voiceVideoCallingSdk = await facadeChatSDK.getVoiceVideoCalling();
      if (voiceVideoCallingSdk && voiceVideoCallingSdk.isInACall()) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        callId = voiceVideoCallingSdk.callId;
        voiceVideoCallingSdk.stopCall();
        _TelemetryHelper.TelemetryHelper.logCallingEvent(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.EndCallButtonClick
        }, callId);
        callingStateCleanUp(dispatch);
      }
    }
  } catch (error) {
    _TelemetryHelper.TelemetryHelper.logCallingEvent(_TelemetryConstants.LogLevel.ERROR, {
      Event: _TelemetryConstants.TelemetryEvent.EndCallButtonClickException,
      ExceptionDetails: {
        exception: `Failed to End Call:  ${error}`
      }
    }, callId);
  }
};
exports.endVoiceVideoCallIfOngoing = endVoiceVideoCallIfOngoing;
const closeChatWidget = dispatch => {
  // Embedded chat
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
    payload: _ConversationState.ConversationState.Closed
  });
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const chatTokenCleanUp = async dispatch => {
  //Just do cleanup here
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CHAT_TOKEN,
    payload: undefined
  });

  // Need to keep liveChatContext until chat is fully closed to for transcript download/email
};

const getEndChatEventName = async (facadeChatSDK, props) => {
  var _facadeChatSDK$getCha2, _facadeChatSDK$getCha3, _facadeChatSDK$getCha4, _facadeChatSDK$getCha5, _props$controlProps2;
  return (0, _utils.getWidgetEndChatEventName)((_facadeChatSDK$getCha2 = facadeChatSDK.getChatSDK()) === null || _facadeChatSDK$getCha2 === void 0 ? void 0 : (_facadeChatSDK$getCha3 = _facadeChatSDK$getCha2.omnichannelConfig) === null || _facadeChatSDK$getCha3 === void 0 ? void 0 : _facadeChatSDK$getCha3.orgId, (_facadeChatSDK$getCha4 = facadeChatSDK.getChatSDK()) === null || _facadeChatSDK$getCha4 === void 0 ? void 0 : (_facadeChatSDK$getCha5 = _facadeChatSDK$getCha4.omnichannelConfig) === null || _facadeChatSDK$getCha5 === void 0 ? void 0 : _facadeChatSDK$getCha5.widgetId, (props === null || props === void 0 ? void 0 : (_props$controlProps2 = props.controlProps) === null || _props$controlProps2 === void 0 ? void 0 : _props$controlProps2.widgetInstanceId) ?? "");
};