"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setPostChatContextAndLoadSurvey = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _ConversationState = require("../../../contexts/common/ConversationState");
var _LiveChatWidgetActionType = require("../../../contexts/common/LiveChatWidgetActionType");
var _Constants = require("../../../common/Constants");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _liveChatConfigUtils = require("./liveChatConfigUtils");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const setPostChatContextAndLoadSurvey = async (facadeChatSDK, dispatch, persistedChat) => {
  try {
    const postChatEnabled = await (0, _liveChatConfigUtils.isPostChatSurveyEnabled)(facadeChatSDK);
    if (postChatEnabled) {
      if (!persistedChat) {
        _TelemetryHelper.TelemetryHelper.logSDKEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.PostChatContextCallStarted,
          Description: _Constants.PostChatSurveyTelemetryMessage.PostChatContextCallStarted
        });
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const context = await facadeChatSDK.getPostChatSurveyContext();
        _TelemetryHelper.TelemetryHelper.logSDKEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.PostChatContextCallSucceed,
          Description: _Constants.PostChatSurveyTelemetryMessage.PostChatContextCallSucceed
        });
        dispatch({
          type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_POST_CHAT_CONTEXT,
          payload: context
        });
      }
    }
  } catch (ex) {
    _TelemetryHelper.TelemetryHelper.logSDKEventToAllTelemetry(_TelemetryConstants.LogLevel.ERROR, {
      Event: _TelemetryConstants.TelemetryEvent.PostChatContextCallFailed,
      Description: _Constants.PostChatSurveyTelemetryMessage.PostChatContextCallFailed,
      ExceptionDetails: {
        exception: ex
      }
    });
  }
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  _omnichannelChatComponents.BroadcastService.getMessageByEventName("LoadPostChatSurvey").subscribe(msg => {
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
      payload: _ConversationState.ConversationState.Postchat
    });
  });
};
exports.setPostChatContextAndLoadSurvey = setPostChatContextAndLoadSurvey;