"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setPreChatAndInitiateChat = exports.prepareStartChat = exports.initStartChat = exports.checkIfConversationStillValid = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _Constants = require("../../../common/Constants");
var _utils = require("../../../common/utils");
var _reconnectChatHelper = require("./reconnectChatHelper");
var _startChatErrorHandler = require("./startChatErrorHandler");
var _ActivityStreamHandler = require("./ActivityStreamHandler");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _ConversationState = require("../../../contexts/common/ConversationState");
var _LiveChatWidgetActionType = require("../../../contexts/common/LiveChatWidgetActionType");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _TelemetryManager = require("../../../common/telemetry/TelemetryManager");
var _endChat = require("./endChat");
var _createAdapter = require("./createAdapter");
var _newMessageEventHandler = require("../../../plugins/newMessageEventHandler");
var _FirstMessageTrackerFromBot = require("../../../firstresponselatency/FirstMessageTrackerFromBot");
var _liveChatConfigUtils = require("./liveChatConfigUtils");
var _setPostChatContextAndLoadSurvey = require("./setPostChatContextAndLoadSurvey");
var _persistentChatHelper = require("./persistentChatHelper");
var _updateSessionDataForTelemetry = require("./updateSessionDataForTelemetry");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let optionalParams = {};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let widgetInstanceId;
// eslint-disable-next-line @typescript-eslint/no-explicit-any
let popoutWidgetInstanceId;

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const prepareStartChat = async (props, facadeChatSDK, state, dispatch, setAdapter) => {
  optionalParams = {}; //Resetting to ensure no stale values
  widgetInstanceId = (0, _utils.getWidgetCacheIdfromProps)(props);

  // reconnect > chat from cache
  if ((0, _reconnectChatHelper.isReconnectEnabled)(props.chatConfig) === true && !(0, _reconnectChatHelper.isPersistentEnabled)(props.chatConfig)) {
    const shouldStartChatNormally = await (0, _reconnectChatHelper.handleChatReconnect)(facadeChatSDK, props, dispatch, setAdapter, initStartChat, state);
    if (!shouldStartChatNormally) {
      return;
    }
  }

  // Check if there is any active popout chats in cache
  if (await canStartPopoutChat(props)) {
    return;
  }

  // Can connect to existing chat session
  if (await canConnectToExistingChat(props, facadeChatSDK, state, dispatch, setAdapter)) {
    return;
  }

  // Setting Proactive chat settings
  const isProactiveChat = state.appStates.conversationState === _ConversationState.ConversationState.ProactiveChat;
  const isPreChatEnabledInProactiveChat = state.appStates.proactiveChatStates.proactiveChatEnablePrechat;

  //Setting PreChat and intiate chat
  await setPreChatAndInitiateChat(facadeChatSDK, dispatch, setAdapter, isProactiveChat, isPreChatEnabledInProactiveChat, state, props);
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.prepareStartChat = prepareStartChat;
const setPreChatAndInitiateChat = async (facadeChatSDK, dispatch, setAdapter, isProactiveChat, proactiveChatEnablePrechatState, state, props) => {
  var _props$preChatSurveyP, _props$preChatSurveyP2, _props$controlProps, _state$domainStates, _state$domainStates$l, _state$domainStates$l2, _state$appStates2;
  // This reset needs to be done before to load prechat, because the conversation state changes from close to prechat
  if ((state === null || state === void 0 ? void 0 : state.appStates.conversationState) === _ConversationState.ConversationState.Closed) {
    // Preventive reset to avoid starting chat with previous requestId which could potentially cause problems
    (0, _endChat.chatSDKStateCleanUp)(facadeChatSDK.getChatSDK());
  }

  // Getting prechat Survey Context
  const parseToJson = false;
  const preChatSurveyResponse = (props === null || props === void 0 ? void 0 : (_props$preChatSurveyP = props.preChatSurveyPaneProps) === null || _props$preChatSurveyP === void 0 ? void 0 : (_props$preChatSurveyP2 = _props$preChatSurveyP.controlProps) === null || _props$preChatSurveyP2 === void 0 ? void 0 : _props$preChatSurveyP2.payload) ?? (await facadeChatSDK.getPreChatSurvey(parseToJson));
  let showPrechat = isProactiveChat ? preChatSurveyResponse && proactiveChatEnablePrechatState : preChatSurveyResponse && !(props !== null && props !== void 0 && (_props$controlProps = props.controlProps) !== null && _props$controlProps !== void 0 && _props$controlProps.hidePreChatSurveyPane);
  showPrechat = await (0, _persistentChatHelper.shouldSetPreChatIfPersistentChat)(facadeChatSDK.getChatSDK(), state === null || state === void 0 ? void 0 : (_state$domainStates = state.domainStates) === null || _state$domainStates === void 0 ? void 0 : (_state$domainStates$l = _state$domainStates.liveChatConfig) === null || _state$domainStates$l === void 0 ? void 0 : (_state$domainStates$l2 = _state$domainStates$l.LiveWSAndLiveChatEngJoin) === null || _state$domainStates$l2 === void 0 ? void 0 : _state$domainStates$l2.msdyn_conversationmode, showPrechat);
  if (showPrechat) {
    var _state$domainStates2, _state$domainStates2$, _state$domainStates2$2, _state$domainStates2$3;
    const isOutOfOperatingHours = (state === null || state === void 0 ? void 0 : (_state$domainStates2 = state.domainStates) === null || _state$domainStates2 === void 0 ? void 0 : (_state$domainStates2$ = _state$domainStates2.liveChatConfig) === null || _state$domainStates2$ === void 0 ? void 0 : (_state$domainStates2$2 = _state$domainStates2$.LiveWSAndLiveChatEngJoin) === null || _state$domainStates2$2 === void 0 ? void 0 : (_state$domainStates2$3 = _state$domainStates2$2.OutOfOperatingHours) === null || _state$domainStates2$3 === void 0 ? void 0 : _state$domainStates2$3.toString().toLowerCase()) === "true";
    if (isOutOfOperatingHours) {
      (state === null || state === void 0 ? void 0 : state.appStates.isMinimized) && dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_MINIMIZED,
        payload: false
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
        payload: _ConversationState.ConversationState.OutOfOffice
      });
      return;
    } else {
      var _state$appStates;
      _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.PrechatSurveyExpected
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_PRE_CHAT_SURVEY_RESPONSE,
        payload: preChatSurveyResponse
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
        payload: _ConversationState.ConversationState.Prechat
      });

      // If minimized, maximize the chat, if the state is missing, consider it as minimized
      if ((state === null || state === void 0 ? void 0 : state.appStates.isMinimized) === undefined || (state === null || state === void 0 ? void 0 : (_state$appStates = state.appStates) === null || _state$appStates === void 0 ? void 0 : _state$appStates.isMinimized) === true) {
        var _state$domainStates3, _state$domainStates3$, _state$domainStates4, _state$domainStates4$;
        dispatch({
          type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_MINIMIZED,
          payload: false
        });

        // this event will notify the upper layer to maximize the widget, an event missing during multi-tab scenario.
        _omnichannelChatComponents.BroadcastService.postMessage({
          eventName: _TelemetryConstants.BroadcastEvent.MaximizeChat,
          payload: {
            height: state === null || state === void 0 ? void 0 : (_state$domainStates3 = state.domainStates) === null || _state$domainStates3 === void 0 ? void 0 : (_state$domainStates3$ = _state$domainStates3.widgetSize) === null || _state$domainStates3$ === void 0 ? void 0 : _state$domainStates3$.height,
            width: state === null || state === void 0 ? void 0 : (_state$domainStates4 = state.domainStates) === null || _state$domainStates4 === void 0 ? void 0 : (_state$domainStates4$ = _state$domainStates4.widgetSize) === null || _state$domainStates4$ === void 0 ? void 0 : _state$domainStates4$.width
          }
        });
      }
      return;
    }
  }

  //Initiate start chat
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
    payload: _ConversationState.ConversationState.Loading
  });

  /**
   * Send max event, since there is a path coming from hide button + LCW SDK that intialize the components
   * but dont maximize it.
   * 
   * This is because a new change to control OOH as closed event when a widget is coming from chat.
   */
  if ((state === null || state === void 0 ? void 0 : state.appStates.isMinimized) === undefined || (state === null || state === void 0 ? void 0 : (_state$appStates2 = state.appStates) === null || _state$appStates2 === void 0 ? void 0 : _state$appStates2.isMinimized) === true) {
    var _state$domainStates5, _state$domainStates5$, _state$domainStates6, _state$domainStates6$;
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_MINIMIZED,
      payload: false
    });
    // this event will notify the upper layer to maximize the widget, an event missing during multi-tab scenario.
    _omnichannelChatComponents.BroadcastService.postMessage({
      eventName: _TelemetryConstants.BroadcastEvent.MaximizeChat,
      payload: {
        height: state === null || state === void 0 ? void 0 : (_state$domainStates5 = state.domainStates) === null || _state$domainStates5 === void 0 ? void 0 : (_state$domainStates5$ = _state$domainStates5.widgetSize) === null || _state$domainStates5$ === void 0 ? void 0 : _state$domainStates5$.height,
        width: state === null || state === void 0 ? void 0 : (_state$domainStates6 = state.domainStates) === null || _state$domainStates6 === void 0 ? void 0 : (_state$domainStates6$ = _state$domainStates6.widgetSize) === null || _state$domainStates6$ === void 0 ? void 0 : _state$domainStates6$.width
      }
    });
  }
  const optionalParams = {
    isProactiveChat
  };
  (0, _FirstMessageTrackerFromBot.createTrackingForFirstMessage)();
  await initStartChat(facadeChatSDK, dispatch, setAdapter, state, props, optionalParams);
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.setPreChatAndInitiateChat = setPreChatAndInitiateChat;
const initStartChat = async (facadeChatSDK, dispatch, setAdapter, state, props, params, persistedState) => {
  var _state$domainStates7, _state$domainStates7$, _state$domainStates7$2;
  let isStartChatSuccessful = false;
  const persistentChatEnabled = await (0, _liveChatConfigUtils.isPersistentChatEnabled)(state === null || state === void 0 ? void 0 : (_state$domainStates7 = state.domainStates) === null || _state$domainStates7 === void 0 ? void 0 : (_state$domainStates7$ = _state$domainStates7.liveChatConfig) === null || _state$domainStates7$ === void 0 ? void 0 : (_state$domainStates7$2 = _state$domainStates7$.LiveWSAndLiveChatEngJoin) === null || _state$domainStates7$2 === void 0 ? void 0 : _state$domainStates7$2.msdyn_conversationmode);
  if ((state === null || state === void 0 ? void 0 : state.appStates.conversationState) === _ConversationState.ConversationState.Closed) {
    // Preventive reset to avoid starting chat with previous requestId which could potentially cause problems
    (0, _endChat.chatSDKStateCleanUp)(facadeChatSDK.getChatSDK());
  }
  try {
    var _state$appStates3;
    // Clear disconnect state on start chat
    (state === null || state === void 0 ? void 0 : (_state$appStates3 = state.appStates) === null || _state$appStates3 === void 0 ? void 0 : _state$appStates3.chatDisconnectEventReceived) && dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CHAT_DISCONNECT_EVENT_RECEIVED,
      payload: false
    });

    //Start widget load timer
    _TelemetryManager.TelemetryTimers.WidgetLoadTimer = (0, _utils.createTimer)();
    _TelemetryHelper.TelemetryHelper.logLoadingEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.WidgetLoadStarted,
      Description: "Widget start chat started."
    });

    //Check if chat retrieved from cache
    if (persistedState || params !== null && params !== void 0 && params.liveChatContext) {
      var _persistedState$domai, _persistedState$domai2, _persistedState$domai3, _persistedState$domai4, _persistedState$domai5;
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.ChatRetrievedFromCache,
        payload: {
          chatId: persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai = persistedState.domainStates) === null || _persistedState$domai === void 0 ? void 0 : (_persistedState$domai2 = _persistedState$domai.liveChatContext) === null || _persistedState$domai2 === void 0 ? void 0 : (_persistedState$domai3 = _persistedState$domai2.chatToken) === null || _persistedState$domai3 === void 0 ? void 0 : _persistedState$domai3.chatId,
          requestId: persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai4 = persistedState.domainStates) === null || _persistedState$domai4 === void 0 ? void 0 : (_persistedState$domai5 = _persistedState$domai4.liveChatContext) === null || _persistedState$domai5 === void 0 ? void 0 : _persistedState$domai5.requestId
        }
      });
    }
    try {
      var _window$Microsoft, _window$Microsoft$Dyn, _window$Microsoft$Dyn2, _window$Microsoft$Dyn3;
      // Set custom context params
      await setCustomContextParams(state, props);
      const defaultOptionalParams = {
        sendDefaultInitContext: true,
        isProactiveChat: !!(params !== null && params !== void 0 && params.isProactiveChat),
        portalContactId: (_window$Microsoft = window.Microsoft) === null || _window$Microsoft === void 0 ? void 0 : (_window$Microsoft$Dyn = _window$Microsoft.Dynamic365) === null || _window$Microsoft$Dyn === void 0 ? void 0 : (_window$Microsoft$Dyn2 = _window$Microsoft$Dyn.Portal) === null || _window$Microsoft$Dyn2 === void 0 ? void 0 : (_window$Microsoft$Dyn3 = _window$Microsoft$Dyn2.User) === null || _window$Microsoft$Dyn3 === void 0 ? void 0 : _window$Microsoft$Dyn3.contactId
      };
      const startChatOptionalParams = Object.assign({}, params, optionalParams, defaultOptionalParams);
      await facadeChatSDK.startChat(startChatOptionalParams);
      isStartChatSuccessful = true;
    } catch (error) {
      (0, _utils.checkContactIdError)(error);
      _TelemetryHelper.TelemetryHelper.logSDKEvent(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.StartChatMethodException,
        ExceptionDetails: {
          exception: `Failed to setup startChat: ${error}`
        }
      });
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.OnWidgetError,
        payload: {
          errorMessage: error
        }
      });
      isStartChatSuccessful = false;
      throw error;
    }
    await createAdapterAndSubscribe(facadeChatSDK, dispatch, setAdapter, props);

    // Set app state to Active
    if (isStartChatSuccessful) {
      _ActivityStreamHandler.ActivityStreamHandler.uncork();
      // Update start chat failure app state if chat loads successfully
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_START_CHAT_FAILING,
        payload: false
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
        payload: _ConversationState.ConversationState.Active
      });
    }
    if (persistedState) {
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_WIDGET_STATE,
        payload: persistedState
      });
      (0, _startChatErrorHandler.logWidgetLoadComplete)(_Constants.WidgetLoadTelemetryMessage.PersistedStateRetrievedMessage);
      // Set post chat context in state, load in background to do not block the load
      (0, _setPostChatContextAndLoadSurvey.setPostChatContextAndLoadSurvey)(facadeChatSDK, dispatch, true);
      return;
    }

    // Persistent Chat relies on the `reconnectId` retrieved from reconnectablechats API to reconnect upon start chat and not `liveChatContext`
    if (!persistentChatEnabled) {
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      const liveChatContext = await (facadeChatSDK === null || facadeChatSDK === void 0 ? void 0 : facadeChatSDK.getCurrentLiveChatContext());
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_LIVE_CHAT_CONTEXT,
        payload: liveChatContext
      });
    }
    (0, _startChatErrorHandler.logWidgetLoadComplete)();
    // Set post chat context in state, load in background to do not block the load
    (0, _setPostChatContextAndLoadSurvey.setPostChatContextAndLoadSurvey)(facadeChatSDK, dispatch);
    // Updating chat session detail for telemetry
    await (0, _updateSessionDataForTelemetry.updateTelemetryData)(facadeChatSDK, dispatch);
  } catch (ex) {
    (0, _startChatErrorHandler.handleStartChatError)(dispatch, facadeChatSDK, props, ex, isStartChatSuccessful);
  } finally {
    optionalParams = {};
    widgetInstanceId = "";
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.initStartChat = initStartChat;
const createAdapterAndSubscribe = async (facadeChatSDK, dispatch, setAdapter, props) => {
  // New adapter creation
  const newAdapter = await (0, _createAdapter.createAdapter)(facadeChatSDK, props);
  setAdapter(newAdapter);
  const chatToken = await (facadeChatSDK === null || facadeChatSDK === void 0 ? void 0 : facadeChatSDK.getChatToken());
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CHAT_TOKEN,
    payload: chatToken
  });
  if (chatToken !== null && chatToken !== void 0 && chatToken.chatId && chatToken !== null && chatToken !== void 0 && chatToken.visitorId) {
    var _newAdapter$activity$;
    newAdapter === null || newAdapter === void 0 ? void 0 : (_newAdapter$activity$ = newAdapter.activity$) === null || _newAdapter$activity$ === void 0 ? void 0 : _newAdapter$activity$.subscribe((0, _newMessageEventHandler.createOnNewAdapterActivityHandler)(chatToken.chatId, chatToken.visitorId));
  }
};
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const canConnectToExistingChat = async (props, facadeChatSDK, state, dispatch, setAdapter) => {
  var _state$appStates4, _persistedState$domai6, _persistedState$appSt;
  // By pass this function in case of popout chat
  if ((state === null || state === void 0 ? void 0 : (_state$appStates4 = state.appStates) === null || _state$appStates4 === void 0 ? void 0 : _state$appStates4.hideStartChatButton) === true) {
    return false;
  }
  const persistedState = (0, _utils.getStateFromCache)((0, _utils.getWidgetCacheIdfromProps)(props));

  //Connect to only active chat session
  if (persistedState && !(0, _utils.isUndefinedOrEmpty)(persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai6 = persistedState.domainStates) === null || _persistedState$domai6 === void 0 ? void 0 : _persistedState$domai6.liveChatContext) && (persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$appSt = persistedState.appStates) === null || _persistedState$appSt === void 0 ? void 0 : _persistedState$appSt.conversationState) === _ConversationState.ConversationState.Active) {
    var _persistedState$domai7;
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_CONVERSATION_STATE,
      payload: _ConversationState.ConversationState.Loading
    });
    const optionalParams = {
      liveChatContext: persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai7 = persistedState.domainStates) === null || _persistedState$domai7 === void 0 ? void 0 : _persistedState$domai7.liveChatContext
    };
    await initStartChat(facadeChatSDK, dispatch, setAdapter, state, props, optionalParams, persistedState);
    return true;
  }
  return false;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const setCustomContextParams = async (state, props) => {
  var _state$domainStates8, _persistedState$domai8;
  if (state !== null && state !== void 0 && (_state$domainStates8 = state.domainStates) !== null && _state$domainStates8 !== void 0 && _state$domainStates8.customContext) {
    var _state$domainStates9;
    optionalParams = Object.assign({}, optionalParams, {
      customContext: JSON.parse(JSON.stringify(state === null || state === void 0 ? void 0 : (_state$domainStates9 = state.domainStates) === null || _state$domainStates9 === void 0 ? void 0 : _state$domainStates9.customContext))
    });
    return;
  }
  if ((0, _utils.isNullOrEmptyString)(widgetInstanceId)) {
    widgetInstanceId = (0, _utils.getWidgetCacheIdfromProps)(props);
  }
  // Add custom context only for unauthenticated chat
  const persistedState = (0, _utils.getStateFromCache)(widgetInstanceId);
  const customContextLocal = (persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai8 = persistedState.domainStates) === null || _persistedState$domai8 === void 0 ? void 0 : _persistedState$domai8.customContext) ?? (props === null || props === void 0 ? void 0 : props.initialCustomContext);
  if (customContextLocal) {
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.SettingCustomContext,
      Description: "Setting custom context for unauthenticated chat"
    });
    optionalParams = Object.assign({}, optionalParams, {
      customContext: JSON.parse(JSON.stringify(customContextLocal))
    });
  } else {
    const customContextFromParent = await getInitContextParamsForPopout();
    if (!(0, _utils.isUndefinedOrEmpty)(customContextFromParent === null || customContextFromParent === void 0 ? void 0 : customContextFromParent.contextVariables)) {
      optionalParams = Object.assign({}, optionalParams, {
        customContext: JSON.parse(JSON.stringify(customContextFromParent.contextVariables))
      });
    }
  }
};
const canStartPopoutChat = async props => {
  if (props.allowSdkChatSupport === false) {
    return false;
  }
  popoutWidgetInstanceId = (0, _utils.getWidgetCacheIdfromProps)(props, true);
  if (!(0, _utils.isNullOrEmptyString)(popoutWidgetInstanceId)) {
    var _persistedState$domai9, _persistedState$appSt2;
    const persistedState = (0, _utils.getStateFromCache)(popoutWidgetInstanceId);
    if (persistedState && !(0, _utils.isUndefinedOrEmpty)(persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$domai9 = persistedState.domainStates) === null || _persistedState$domai9 === void 0 ? void 0 : _persistedState$domai9.liveChatContext) && (persistedState === null || persistedState === void 0 ? void 0 : (_persistedState$appSt2 = persistedState.appStates) === null || _persistedState$appSt2 === void 0 ? void 0 : _persistedState$appSt2.conversationState) === _ConversationState.ConversationState.Active) {
      // Initiate popout chat
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.InitiateStartChatInPopoutMode
      });
      return true;
    }
  }
  return false;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const checkIfConversationStillValid = async (facadeChatSDK, dispatch, state) => {
  var _state$domainStates10, _state$domainStates11, _state$domainStates12;
  const requestIdFromCache = (_state$domainStates10 = state.domainStates) === null || _state$domainStates10 === void 0 ? void 0 : (_state$domainStates11 = _state$domainStates10.liveChatContext) === null || _state$domainStates11 === void 0 ? void 0 : _state$domainStates11.requestId;
  const liveChatContext = state === null || state === void 0 ? void 0 : (_state$domainStates12 = state.domainStates) === null || _state$domainStates12 === void 0 ? void 0 : _state$domainStates12.liveChatContext;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let conversationDetails = undefined;
  // Preserve current requestId
  const currentRequestId = facadeChatSDK.getChatSDK().requestId ?? "";
  dispatch({
    type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_INITIAL_CHAT_SDK_REQUEST_ID,
    payload: currentRequestId
  });
  try {
    facadeChatSDK.getChatSDK().requestId = requestIdFromCache;
    conversationDetails = await (0, _utils.getConversationDetailsCall)(facadeChatSDK, liveChatContext);
    if (Object.keys(conversationDetails).length === 0 || (0, _utils.isNullOrUndefined)(conversationDetails.state) || conversationDetails.state === _Constants.LiveWorkItemState.Closed || conversationDetails.state === _Constants.LiveWorkItemState.WrapUp) {
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_LIVE_CHAT_CONTEXT,
        payload: undefined
      });
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_UNREAD_MESSAGE_COUNT,
        payload: 0
      });
      if (currentRequestId) {
        facadeChatSDK.getChatSDK().requestId = currentRequestId;
      }
      return false;
    }
    return true;
  } catch (error) {
    _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.ERROR, {
      Event: _TelemetryConstants.TelemetryEvent.GetConversationDetailsException,
      ExceptionDetails: {
        exception: `Conversation is not valid: ${error}`
      }
    });
    return false;
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.checkIfConversationStillValid = checkIfConversationStillValid;
const getInitContextParamsForPopout = async () => {
  return window.opener ? await getInitContextParamForPopoutFromOuterScope(window.opener) : null;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const getInitContextParamForPopoutFromOuterScope = async scope => {
  let payload;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let waitPromiseResolve;
  const waitPromise = new Promise((res, rej) => {
    waitPromiseResolve = res;
    setTimeout(() => rej("Failed to find method in outer scope"), 5000);
  }).catch(rej => console.warn(rej));
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const getInitContextParamsFromParent = e => {
    if (e.data && e.data.messageName == _Constants.Constants.InitContextParamsResponse) {
      payload = e.data.payload;
      waitPromiseResolve();
    }
  };
  window.addEventListener("message", getInitContextParamsFromParent, false);
  scope.postMessage({
    messageName: _Constants.Constants.InitContextParamsRequest
  }, "*");
  await waitPromise;
  window.removeEventListener("message", getInitContextParamsFromParent, false);
  return payload;
};