"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.updateTelemetryData = void 0;
var _TelemetryConstants = require("../../../common/telemetry/TelemetryConstants");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _LiveChatWidgetActionType = require("../../../contexts/common/LiveChatWidgetActionType");
var _TelemetryHelper = require("../../../common/telemetry/TelemetryHelper");
var _TelemetryManager = require("../../../common/telemetry/TelemetryManager");
var _utils = require("../../../common/utils");
// eslint-disable-next-line @typescript-eslint/no-explicit-any
const updateTelemetryData = async (facadeChatSDK, dispatch) => {
  // load it concurrently, this will reduce the load time
  await Promise.all([updateSessionDataForTelemetry(facadeChatSDK, dispatch), updateConversationDataForTelemetry(facadeChatSDK, dispatch)]);
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
exports.updateTelemetryData = updateTelemetryData;
const updateSessionDataForTelemetry = async (facadeChatSDK, dispatch) => {
  if (facadeChatSDK && facadeChatSDK.getChatSDK()) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const chatSession = await facadeChatSDK.getCurrentLiveChatContext();
    const telemetryData = _TelemetryHelper.TelemetryHelper.addSessionDataToTelemetry(chatSession, _TelemetryManager.TelemetryManager.InternalTelemetryData);
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_TELEMETRY_DATA,
      payload: telemetryData
    });
    _omnichannelChatComponents.BroadcastService.postMessage({
      eventName: _TelemetryConstants.BroadcastEvent.UpdateSessionDataForTelemetry,
      payload: {
        chatSession
      }
    });
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const updateConversationDataForTelemetry = async (facadeChatSDK, dispatch) => {
  if (facadeChatSDK && facadeChatSDK.getChatSDK()) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const liveWorkItem = await (0, _utils.getConversationDetailsCall)(facadeChatSDK);
    const telemetryData = _TelemetryHelper.TelemetryHelper.addConversationDataToTelemetry(liveWorkItem, _TelemetryManager.TelemetryManager.InternalTelemetryData);
    dispatch({
      type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_TELEMETRY_DATA,
      payload: telemetryData
    });
    _omnichannelChatComponents.BroadcastService.postMessage({
      eventName: _TelemetryConstants.BroadcastEvent.UpdateConversationDataForTelemetry,
      payload: {
        liveWorkItem
      }
    });
  }
};