"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.NotificationPaneStateful = void 0;
var _Constants = require("../../common/Constants");
var _TelemetryConstants = require("../../common/telemetry/TelemetryConstants");
var _react = _interopRequireWildcard(require("react"));
var _LiveChatWidgetActionType = require("../../contexts/common/LiveChatWidgetActionType");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _NotificationScenarios = require("../webchatcontainerstateful/webchatcontroller/enums/NotificationScenarios");
var _TelemetryHelper = require("../../common/telemetry/TelemetryHelper");
var _utils = require("../../common/utils");
var _defaultChatDisconnectControlProps = require("./defaultProps/defaultChatDisconnectControlProps");
var _defaultChatDisconnectStyleProps = require("./defaultProps/defaultChatDisconnectStyleProps");
var _botframeworkWebchat = require("botframework-webchat");
var _useChatAdapterStore = _interopRequireDefault(require("../../hooks/useChatAdapterStore"));
var _useChatContextStore = _interopRequireDefault(require("../../hooks/useChatContextStore"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
let uiTimer;
const NotificationPaneStateful = props => {
  var _state$domainStates, _state$domainStates3;
  (0, _react.useEffect)(() => {
    uiTimer = (0, _utils.createTimer)();
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXNotificationPaneStart
    });
  }, []);
  const {
    notificationPaneProps,
    notificationScenarioType,
    endChat
  } = props;
  const [state, dispatch] = (0, _useChatContextStore.default)();
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const [adapter] = (0, _useChatAdapterStore.default)();
  const localConfirmationPaneState = (0, _react.useRef)(state === null || state === void 0 ? void 0 : (_state$domainStates = state.domainStates) === null || _state$domainStates === void 0 ? void 0 : _state$domainStates.confirmationState);
  const onCloseChatClick = async () => {
    _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.NotificationCloseChatButtonClicked,
      Description: "Notification Close Chat button clicked."
    });
    if (localConfirmationPaneState.current !== _Constants.ConfirmationState.Ok) {
      dispatch({
        type: _LiveChatWidgetActionType.LiveChatWidgetActionType.SET_SHOW_CONFIRMATION,
        payload: true
      });
    } else {
      const skipEndChatSDK = true;
      const skipCloseChat = false;
      const postMessageToOtherTabs = true;
      await endChat(adapter, skipEndChatSDK, skipCloseChat, postMessageToOtherTabs);
    }
  };
  (0, _react.useEffect)(() => {
    var _state$domainStates2;
    localConfirmationPaneState.current = state === null || state === void 0 ? void 0 : (_state$domainStates2 = state.domainStates) === null || _state$domainStates2 === void 0 ? void 0 : _state$domainStates2.confirmationState;
  }, [state === null || state === void 0 ? void 0 : (_state$domainStates3 = state.domainStates) === null || _state$domainStates3 === void 0 ? void 0 : _state$domainStates3.confirmationState]);
  const {
    useDismissNotification
  } = _botframeworkWebchat.hooks;
  const dismissNotification = useDismissNotification();
  const handleDismissNotification = (0, _react.useCallback)(() => {
    _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.NotificationDismissButtonClicked,
      Description: `${notificationScenarioType} Notification Dismiss button clicked.`
    });
    dismissNotification(notificationScenarioType ?? "");
  }, [notificationScenarioType]);

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateTitleInternalProps = notificationProps => {
    var _notificationProps$co, _notificationProps$co2, _notificationProps$st, _notificationProps$st2, _notificationProps$st3, _defaultChatDisconnec;
    return {
      hideTitle: ((_notificationProps$co = notificationProps.controlProps) === null || _notificationProps$co === void 0 ? void 0 : _notificationProps$co.hideTitle) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideTitle,
      titleText: ((_notificationProps$co2 = notificationProps.controlProps) === null || _notificationProps$co2 === void 0 ? void 0 : _notificationProps$co2.titleText) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.titleText,
      titleStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.titleStyleProps, (_notificationProps$st = notificationProps.styleProps) === null || _notificationProps$st === void 0 ? void 0 : _notificationProps$st.titleStyleProps),
      titleClassName: ((_notificationProps$st2 = notificationProps.styleProps) === null || _notificationProps$st2 === void 0 ? void 0 : (_notificationProps$st3 = _notificationProps$st2.classNames) === null || _notificationProps$st3 === void 0 ? void 0 : _notificationProps$st3.titleClassName) ?? ((_defaultChatDisconnec = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec === void 0 ? void 0 : _defaultChatDisconnec.titleClassName)
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateSubtitleInternalProps = notificationProps => {
    var _notificationProps$co3, _notificationProps$co4, _notificationProps$st4, _notificationProps$st5, _notificationProps$st6, _defaultChatDisconnec2;
    return {
      hideSubtitle: ((_notificationProps$co3 = notificationProps.controlProps) === null || _notificationProps$co3 === void 0 ? void 0 : _notificationProps$co3.hideSubtitle) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideSubtitle,
      subtitleText: ((_notificationProps$co4 = notificationProps.controlProps) === null || _notificationProps$co4 === void 0 ? void 0 : _notificationProps$co4.subtitleText) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.subtitleText,
      subtitleStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.subtitleStyleProps, (_notificationProps$st4 = notificationProps.styleProps) === null || _notificationProps$st4 === void 0 ? void 0 : _notificationProps$st4.subtitleStyleProps),
      subtitleClassName: ((_notificationProps$st5 = notificationProps.styleProps) === null || _notificationProps$st5 === void 0 ? void 0 : (_notificationProps$st6 = _notificationProps$st5.classNames) === null || _notificationProps$st6 === void 0 ? void 0 : _notificationProps$st6.subtitleClassName) ?? ((_defaultChatDisconnec2 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec2 === void 0 ? void 0 : _defaultChatDisconnec2.subtitleClassName)
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateHyperlinkInternalProps = notificationProps => {
    var _notificationProps$co5, _notificationProps$co6, _notificationProps$co7, _notificationProps$co8, _notificationProps$st7, _notificationProps$st8, _notificationProps$st9, _notificationProps$st10, _defaultChatDisconnec3;
    return {
      hideHyperlink: ((_notificationProps$co5 = notificationProps.controlProps) === null || _notificationProps$co5 === void 0 ? void 0 : _notificationProps$co5.hideHyperlink) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideHyperlink,
      hyperlinkText: ((_notificationProps$co6 = notificationProps.controlProps) === null || _notificationProps$co6 === void 0 ? void 0 : _notificationProps$co6.hyperlinkText) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hyperlinkText,
      hyperlinkAriaLabel: ((_notificationProps$co7 = notificationProps.controlProps) === null || _notificationProps$co7 === void 0 ? void 0 : _notificationProps$co7.hyperlinkAriaLabel) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hyperlinkAriaLabel,
      hyperlinkHref: ((_notificationProps$co8 = notificationProps.controlProps) === null || _notificationProps$co8 === void 0 ? void 0 : _notificationProps$co8.hyperlinkHref) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hyperlinkHref,
      hyperlinkStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.hyperlinkStyleProps, (_notificationProps$st7 = notificationProps.styleProps) === null || _notificationProps$st7 === void 0 ? void 0 : _notificationProps$st7.hyperlinkStyleProps),
      hyperlinkHoverStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.hyperlinkHoverStyleProps, (_notificationProps$st8 = notificationProps.styleProps) === null || _notificationProps$st8 === void 0 ? void 0 : _notificationProps$st8.hyperlinkHoverStyleProps),
      hyperlinkClassName: ((_notificationProps$st9 = notificationProps.styleProps) === null || _notificationProps$st9 === void 0 ? void 0 : (_notificationProps$st10 = _notificationProps$st9.classNames) === null || _notificationProps$st10 === void 0 ? void 0 : _notificationProps$st10.hyperlinkClassName) ?? ((_defaultChatDisconnec3 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec3 === void 0 ? void 0 : _defaultChatDisconnec3.hyperlinkClassName)
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateNotificationIconInternalProps = notificationProps => {
    var _notificationProps$co9, _notificationProps$co10, _notificationProps$st11, _notificationProps$st12, _notificationProps$st13, _defaultChatDisconnec4, _notificationProps$st14;
    return {
      hideNotificationIcon: ((_notificationProps$co9 = notificationProps.controlProps) === null || _notificationProps$co9 === void 0 ? void 0 : _notificationProps$co9.hideIcon) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideIcon,
      notificationIconProps: Object.assign({}, _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.notificationIconProps, (_notificationProps$co10 = notificationProps.controlProps) === null || _notificationProps$co10 === void 0 ? void 0 : _notificationProps$co10.notificationIconProps),
      notificationIconStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.notificationIconStyleProps, (_notificationProps$st11 = notificationProps.styleProps) === null || _notificationProps$st11 === void 0 ? void 0 : _notificationProps$st11.notificationIconStyleProps),
      notificationIconClassName: ((_notificationProps$st12 = notificationProps.styleProps) === null || _notificationProps$st12 === void 0 ? void 0 : (_notificationProps$st13 = _notificationProps$st12.classNames) === null || _notificationProps$st13 === void 0 ? void 0 : _notificationProps$st13.notificationIconClassName) ?? ((_defaultChatDisconnec4 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec4 === void 0 ? void 0 : _defaultChatDisconnec4.notificationIconClassName),
      notificationIconContainerStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.notificationIconContainerStyleProps, (_notificationProps$st14 = notificationProps.styleProps) === null || _notificationProps$st14 === void 0 ? void 0 : _notificationProps$st14.notificationIconContainerStyleProps)
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateDismissButtonInternalProps = notificationProps => {
    var _notificationProps$co11, _notificationProps$co12, _notificationProps$st15, _notificationProps$st16, _notificationProps$st17, _notificationProps$st18, _defaultChatDisconnec5;
    return {
      hideDismissButton: ((_notificationProps$co11 = notificationProps.controlProps) === null || _notificationProps$co11 === void 0 ? void 0 : _notificationProps$co11.hideDismissButton) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideDismissButton,
      dismissButtonProps: Object.assign({
        onClick: handleDismissNotification
      }, _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.dismissButtonProps, (_notificationProps$co12 = notificationProps.controlProps) === null || _notificationProps$co12 === void 0 ? void 0 : _notificationProps$co12.dismissButtonProps),
      dismissButtonStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.dismissButtonStyleProps, (_notificationProps$st15 = notificationProps.styleProps) === null || _notificationProps$st15 === void 0 ? void 0 : _notificationProps$st15.dismissButtonStyleProps),
      dismissButtonHoverStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.dismissButtonHoverStyleProps, (_notificationProps$st16 = notificationProps.styleProps) === null || _notificationProps$st16 === void 0 ? void 0 : _notificationProps$st16.dismissButtonHoverStyleProps),
      dismissButtonClassName: ((_notificationProps$st17 = notificationProps.styleProps) === null || _notificationProps$st17 === void 0 ? void 0 : (_notificationProps$st18 = _notificationProps$st17.classNames) === null || _notificationProps$st18 === void 0 ? void 0 : _notificationProps$st18.dismissButtonClassName) ?? ((_defaultChatDisconnec5 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec5 === void 0 ? void 0 : _defaultChatDisconnec5.dismissButtonClassName)
    };
  };

  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateCloseChatButtonInternalProps = notificationProps => {
    var _notificationProps$co13, _notificationProps$co14, _notificationProps$st19, _notificationProps$st20, _notificationProps$st21, _notificationProps$st22, _defaultChatDisconnec6;
    return {
      hideCloseChatButton: ((_notificationProps$co13 = notificationProps.controlProps) === null || _notificationProps$co13 === void 0 ? void 0 : _notificationProps$co13.hideCloseChatButton) ?? _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.hideCloseChatButton,
      closeChatButtonProps: Object.assign({
        onClick: onCloseChatClick
      }, _defaultChatDisconnectControlProps.defaultChatDisconnectControlProps.closeChatButtonProps, (_notificationProps$co14 = notificationProps.controlProps) === null || _notificationProps$co14 === void 0 ? void 0 : _notificationProps$co14.closeChatButtonProps),
      closeChatButtonStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.closeChatButtonStyleProps, (_notificationProps$st19 = notificationProps.styleProps) === null || _notificationProps$st19 === void 0 ? void 0 : _notificationProps$st19.closeChatButtonStyleProps),
      closeChatButtonHoverStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.closeChatButtonHoverStyleProps, (_notificationProps$st20 = notificationProps.styleProps) === null || _notificationProps$st20 === void 0 ? void 0 : _notificationProps$st20.closeChatButtonHoverStyleProps),
      closeChatButtonClassName: ((_notificationProps$st21 = notificationProps.styleProps) === null || _notificationProps$st21 === void 0 ? void 0 : (_notificationProps$st22 = _notificationProps$st21.classNames) === null || _notificationProps$st22 === void 0 ? void 0 : _notificationProps$st22.closeChatButtonClassName) ?? ((_defaultChatDisconnec6 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec6 === void 0 ? void 0 : _defaultChatDisconnec6.closeChatButtonClassName)
    };
  };
  let genericPropsObj = {};

  // Populate INotificationPaneInternal after merging customized props with default props
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  const populateInternalProps = notificationProps => {
    var _notificationProps$st23, _notificationProps$st24, _notificationProps$st25, _defaultChatDisconnec7, _notificationProps$st26, _notificationProps$st27;
    if (!notificationProps) {
      notificationProps = {};
    }
    genericPropsObj = {
      id: notificationProps.id ?? _Constants.NotificationPaneConstants.DefaultNotificationPaneId,
      dir: notificationProps.dir,
      generalStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.generalStyleProps, (_notificationProps$st23 = notificationProps.styleProps) === null || _notificationProps$st23 === void 0 ? void 0 : _notificationProps$st23.generalStyleProps),
      containerClassName: ((_notificationProps$st24 = notificationProps.styleProps) === null || _notificationProps$st24 === void 0 ? void 0 : (_notificationProps$st25 = _notificationProps$st24.classNames) === null || _notificationProps$st25 === void 0 ? void 0 : _notificationProps$st25.containerClassName) ?? ((_defaultChatDisconnec7 = _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.classNames) === null || _defaultChatDisconnec7 === void 0 ? void 0 : _defaultChatDisconnec7.containerClassName),
      componentOverrides: notificationProps.componentOverrides,
      infoGroupStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.infoGroupStyleProps, (_notificationProps$st26 = notificationProps.styleProps) === null || _notificationProps$st26 === void 0 ? void 0 : _notificationProps$st26.infoGroupStyleProps),
      buttonGroupStyleProps: Object.assign({}, _defaultChatDisconnectStyleProps.defaultChatDisconnectStyleProps.buttonGroupStyleProps, (_notificationProps$st27 = notificationProps.styleProps) === null || _notificationProps$st27 === void 0 ? void 0 : _notificationProps$st27.buttonGroupStyleProps),
      ...populateTitleInternalProps(notificationProps),
      ...populateSubtitleInternalProps(notificationProps),
      ...populateHyperlinkInternalProps(notificationProps),
      ...populateNotificationIconInternalProps(notificationProps),
      ...populateDismissButtonInternalProps(notificationProps),
      ...populateCloseChatButtonInternalProps(notificationProps)
    };
  };
  switch (notificationScenarioType) {
    case _NotificationScenarios.NotificationScenarios.ChatDisconnect:
      populateInternalProps(notificationPaneProps === null || notificationPaneProps === void 0 ? void 0 : notificationPaneProps.chatDisconnectNotificationProps);
      break;
    // TODO additional scenarios to be added...
  }

  (0, _react.useEffect)(() => {
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXNotificationPaneCompleted,
      ElapsedTimeInMilliseconds: uiTimer.milliSecondsElapsed
    });
  }, []);
  return /*#__PURE__*/_react.default.createElement(_omnichannelChatComponents.NotificationPane, genericPropsObj);
};
exports.NotificationPaneStateful = NotificationPaneStateful;
var _default = NotificationPaneStateful;
exports.default = _default;