"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.OutOfOfficeHoursPaneStateful = void 0;
var _TelemetryConstants = require("../../common/telemetry/TelemetryConstants");
var _react = _interopRequireWildcard(require("react"));
var _utils = require("../../common/utils");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _TelemetryHelper = require("../../common/telemetry/TelemetryHelper");
var _defaultgeneralOOOHPaneStyleProps = require("./common/defaultStyleProps/defaultgeneralOOOHPaneStyleProps");
var _xssUtils = require("../../common/utils/xssUtils");
var _useChatContextStore = _interopRequireDefault(require("../../hooks/useChatContextStore"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
let uiTimer;
const OOOHPaneTitleText = "Thanks for contacting us. You have reached us outside of our operating hours. An agent will respond when we open.";
const OutOfOfficeHoursPaneStateful = props => {
  var _props$styleProps;
  (0, _react.useEffect)(() => {
    uiTimer = (0, _utils.createTimer)();
    _TelemetryHelper.TelemetryHelper.logLoadingEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXOutOfOfficeHoursPaneStart,
      Description: "Out of office hours pane loading started."
    });
  }, []);
  const [state] = (0, _useChatContextStore.default)();
  const generalStyleProps = Object.assign({}, _defaultgeneralOOOHPaneStyleProps.defaultGeneralStyleProps, (_props$styleProps = props.styleProps) === null || _props$styleProps === void 0 ? void 0 : _props$styleProps.generalStyleProps);
  const styleProps = {
    ...props.styleProps,
    generalStyleProps: generalStyleProps
  };
  const controlProps = {
    id: "oc-lcw-outofofficehours-pane",
    dir: state.domainStates.globalDir,
    ...props.controlProps
  };

  // Move focus to the first button
  (0, _react.useEffect)(() => {
    if (state.domainStates.widgetElementId !== null && state.domainStates.widgetElementId !== undefined && state.domainStates.widgetElementId.trim() !== "") {
      const firstElement = (0, _utils.findAllFocusableElement)(`#${state.domainStates.widgetElementId}`);
      if (firstElement && firstElement[0]) {
        firstElement[0].focus();
      }
    }
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.OutOfOfficePaneLoaded
    });
    _TelemetryHelper.TelemetryHelper.logLoadingEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.UXOutOfOfficeHoursPaneCompleted,
      Description: "Out of office hours pane loading completed.",
      ElapsedTimeInMilliseconds: uiTimer.milliSecondsElapsed
    });
  }, []);

  // Enhanced titleText sanitization
  if (controlProps !== null && controlProps !== void 0 && controlProps.titleText) {
    const {
      cleanText,
      isXSSDetected
    } = (0, _xssUtils.detectAndCleanXSS)(controlProps.titleText);
    if (!isXSSDetected) {
      // replace with the sanitized text
      controlProps.titleText = cleanText;
    } else {
      _TelemetryHelper.TelemetryHelper.logLoadingEventToAllTelemetry(_TelemetryConstants.LogLevel.WARN, {
        Event: _TelemetryConstants.TelemetryEvent.XSSTextDetected,
        Description: "Potential XSS attempt detected in titleText",
        CustomProperties: {
          originalText: controlProps.titleText.substring(0, 100),
          // Log first 100 chars for analysis
          cleanedText: cleanText.substring(0, 100)
        }
      });
      controlProps.titleText = OOOHPaneTitleText;
    }
  }
  return /*#__PURE__*/_react.default.createElement(_omnichannelChatComponents.OutOfOfficeHoursPane, {
    componentOverrides: props.componentOverrides,
    controlProps: controlProps,
    styleProps: styleProps
  });
};
exports.OutOfOfficeHoursPaneStateful = OutOfOfficeHoursPaneStateful;
var _default = OutOfOfficeHoursPaneStateful;
exports.default = _default;