"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.PostChatSurveyPaneStateful = void 0;
var _TelemetryConstants = require("../../common/telemetry/TelemetryConstants");
var _react = _interopRequireWildcard(require("react"));
var _Constants = require("../../common/Constants");
var _CustomerVoiceEvents = require("./enums/CustomerVoiceEvents");
var _PostChatSurveyMode = require("./enums/PostChatSurveyMode");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _TelemetryHelper = require("../../common/telemetry/TelemetryHelper");
var _defaultgeneralPostChatSurveyPaneStyleProps = require("./common/defaultStyleProps/defaultgeneralPostChatSurveyPaneStyleProps");
var _utils = require("../../common/utils");
var _useChatContextStore = _interopRequireDefault(require("../../hooks/useChatContextStore"));
var _isValidSurveyUrl = _interopRequireDefault(require("./common/isValidSurveyUrl"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const generateSurveyInviteLink = function (surveyInviteLink, isEmbed, locale, compact, customerVoiceSurveyCorrelationId) {
  let showMultiLingual = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
  const surveyLinkParams = new URLSearchParams({
    embed: isEmbed.toString(),
    compact: (compact ?? true).toString(),
    lang: locale ?? "en-us",
    showmultilingual: (showMultiLingual ?? false).toString(),
    cvResponsePageRequestId: customerVoiceSurveyCorrelationId
  });
  return `${surveyInviteLink}&${surveyLinkParams.toString()}`;
};
const PostChatSurveyPaneStateful = props => {
  var _props$styleProps, _state$appStates, _props$controlProps;
  const [state] = (0, _useChatContextStore.default)();
  const generalStyleProps = Object.assign({}, _defaultgeneralPostChatSurveyPaneStyleProps.defaultGeneralPostChatSurveyPaneStyleProps, (_props$styleProps = props.styleProps) === null || _props$styleProps === void 0 ? void 0 : _props$styleProps.generalStyleProps, {
    display: state.appStates.isMinimized ? "none" : "contents"
  });
  let surveyInviteLink = "";
  const surveyMode = (state === null || state === void 0 ? void 0 : (_state$appStates = state.appStates) === null || _state$appStates === void 0 ? void 0 : _state$appStates.selectedSurveyMode) === _PostChatSurveyMode.PostChatSurveyMode.Embed;
  if (state.domainStates.postChatContext.botSurveyInviteLink &&
  // Bot survey enabled
  state.appStates.postChatParticipantType === _Constants.ParticipantType.Bot) {
    // Only Bot has engaged
    surveyInviteLink = generateSurveyInviteLink(state.domainStates.postChatContext.botSurveyInviteLink, surveyMode, state.domainStates.postChatContext.botFormsProLocale, props.isCustomerVoiceSurveyCompact ?? true, props.customerVoiceSurveyCorrelationId || "");
  } else {
    surveyInviteLink = generateSurveyInviteLink(state.domainStates.postChatContext.surveyInviteLink, surveyMode, state.domainStates.postChatContext.formsProLocale, props.isCustomerVoiceSurveyCompact ?? true, props.customerVoiceSurveyCorrelationId || "");
  }
  if (props.copilotSurveyContext) {
    surveyInviteLink = `${surveyInviteLink}&mcs_additionalcontext=${JSON.stringify(props.copilotSurveyContext)}`;
  }
  const styleProps = {
    ...props.styleProps,
    generalStyleProps: generalStyleProps
  };
  const controlProps = {
    id: "oc-lcw-postchatsurvey-pane",
    surveyURL: ((_props$controlProps = props.controlProps) === null || _props$controlProps === void 0 ? void 0 : _props$controlProps.surveyURL) ?? surveyInviteLink,
    ...props.controlProps
  };
  if (controlProps.surveyURL) {
    if (!(0, _isValidSurveyUrl.default)(controlProps.surveyURL)) {
      _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.ERROR, {
        Event: _TelemetryConstants.TelemetryEvent.PostChatSurveyUrlValidationFailed,
        Description: `${controlProps.surveyURL} is not a valid Survey URL`
      });
      controlProps.surveyURL = "";
    } else {
      _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.PostChatSurveyUrlValidationCompleted,
        Description: `${controlProps.surveyURL} is a valid Survey URL`
      });
    }
  }

  // Move focus to the first button
  (0, _react.useEffect)(() => {
    const firstElement = (0, _utils.findAllFocusableElement)(`#${controlProps.id}`);
    if (firstElement && firstElement[0]) {
      firstElement[0].focus();
    }
    _TelemetryHelper.TelemetryHelper.logLoadingEvent(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.PostChatSurveyLoaded
    });

    //Customer Voice Telemetry Events
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    window.addEventListener("message", message => {
      const {
        data
      } = message;
      if (!data) return;
      if (data === _CustomerVoiceEvents.CustomerVoiceEvents.ResponsePageLoaded) {
        _TelemetryHelper.TelemetryHelper.logActionEvent(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.CustomerVoiceResponsePageLoaded
        });
      } else if (data === _CustomerVoiceEvents.CustomerVoiceEvents.FormResponseSubmitted) {
        _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
          Event: _TelemetryConstants.TelemetryEvent.CustomerVoiceFormResponseSubmitted,
          Description: "Customer Voice form response submitted."
        });
      } else if (data === _CustomerVoiceEvents.CustomerVoiceEvents.FormResponseError) {
        _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.ERROR, {
          Event: _TelemetryConstants.TelemetryEvent.CustomerVoiceFormResponseError,
          Description: "Customer Voice form response error.",
          ExceptionDetails: {
            message: "Customer Voice form response error."
          }
        });
      } else if (typeof data === "string" && data.startsWith(_CustomerVoiceEvents.CustomerVoiceEvents.FormsError)) {
        _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.ERROR, {
          Event: _TelemetryConstants.TelemetryEvent.CustomerVoiceFormsError,
          Description: "Customer Voice failed to load with forms error.",
          ExceptionDetails: {
            message: `Customer Voice forms error details: ${data}`
          }
        });
      }
    });
  }, []);
  return /*#__PURE__*/_react.default.createElement(_omnichannelChatComponents.PostChatSurveyPane, {
    controlProps: controlProps,
    styleProps: styleProps
  });
};
exports.PostChatSurveyPaneStateful = PostChatSurveyPaneStateful;
var _default = PostChatSurveyPaneStateful;
exports.default = _default;