"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.postSystemMessageActivity = exports.postEchoActivity = exports.postBotTypingActivity = exports.postBotMessageActivity = exports.postBotAttachmentActivity = exports.customerUser = exports.botUser = void 0;
var _omnichannelChatSdk = require("@microsoft/omnichannel-chat-sdk");
const customerUser = {
  id: "usedId",
  name: "User",
  role: "user"
};
exports.customerUser = customerUser;
const botUser = {
  id: "botId",
  name: "Bot",
  role: "bot"
};

// WebChat expects an "echo" activity to confirm the message has been sent successfully
exports.botUser = botUser;
const postEchoActivity = function (activityObserver, activity, user) {
  let delay = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1000;
  const echoActivity = {
    ...activity,
    id: (0, _omnichannelChatSdk.uuidv4)(),
    from: {
      ...activity.from,
      ...user
    },
    timestamp: new Date().toISOString()
  };
  setTimeout(() => {
    activityObserver === null || activityObserver === void 0 ? void 0 : activityObserver.next(echoActivity); // mock message sent activity
  }, delay);
};
exports.postEchoActivity = postEchoActivity;
const postBotMessageActivity = function (activityObserver, text) {
  let tags = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : "";
  let delay = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1000;
  setTimeout(() => {
    activityObserver === null || activityObserver === void 0 ? void 0 : activityObserver.next({
      id: (0, _omnichannelChatSdk.uuidv4)(),
      from: {
        ...botUser
      },
      text,
      type: "message",
      channelData: {
        tags
      },
      timestamp: new Date().toISOString()
    });
  }, delay);
};
exports.postBotMessageActivity = postBotMessageActivity;
const postSystemMessageActivity = function (activityObserver, text) {
  let delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1000;
  postBotMessageActivity(activityObserver, text, "system", delay);
};
exports.postSystemMessageActivity = postSystemMessageActivity;
const postBotTypingActivity = function (activityObserver) {
  let delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1000;
  setTimeout(() => {
    activityObserver === null || activityObserver === void 0 ? void 0 : activityObserver.next({
      id: (0, _omnichannelChatSdk.uuidv4)(),
      from: {
        ...botUser
      },
      type: "typing"
    });
  }, delay);
};
exports.postBotTypingActivity = postBotTypingActivity;
const postBotAttachmentActivity = function (activityObserver) {
  let attachments = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  let delay = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1000;
  setTimeout(() => {
    activityObserver === null || activityObserver === void 0 ? void 0 : activityObserver.next({
      id: (0, _omnichannelChatSdk.uuidv4)(),
      from: {
        ...botUser
      },
      attachments,
      type: "message",
      timestamp: new Date().toISOString()
    });
  }, delay);
};
exports.postBotAttachmentActivity = postBotAttachmentActivity;