"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAttachmentMiddleware = void 0;
var _Constants = require("../../../../../common/Constants");
var _react = _interopRequireDefault(require("react"));
var _FileAttachmentIconManager = require("../../../common/utils/FileAttachmentIconManager");
var _Attachment = _interopRequireDefault(require("./attachments/Attachment"));
var _TelemetryConstants = require("../../../../../common/telemetry/TelemetryConstants");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _FileScanStatus = _interopRequireDefault(require("./attachments/FileScanStatus"));
var _MaliciousAttachment = _interopRequireDefault(require("./attachments/MaliciousAttachment"));
var _NotificationHandler = require("../../notification/NotificationHandler");
var _NotificationScenarios = require("../../enums/NotificationScenarios");
var _ScanInProgressAttachment = _interopRequireDefault(require("./attachments/ScanInProgressAttachment"));
var _WebChatActionType = require("../../enums/WebChatActionType");
var _defaultAtttachmentAdaptiveCardStyles = require("./defaultStyles/defaultAtttachmentAdaptiveCardStyles");
var _defaultAttachmentProps = require("../../../common/defaultProps/defaultAttachmentProps");
var _defaultMiddlewareLocalizedTexts = require("../../../common/defaultProps/defaultMiddlewareLocalizedTexts");
var _ = require("../../../../..");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/* eslint-disable @typescript-eslint/no-explicit-any */
/******
 * AttachmentMiddleware
 *
 * Handles attachment downloading.
 ******/

/**
* Patch card with different attachment data.
* @param card
* @param newAttachment
*/
const patchAttachment = (card, newAttachment) => {
  const {
    activity,
    attachment
  } = card;
  const patchedAttachment = Object.assign({}, attachment);
  patchedAttachment.contentType = newAttachment.contentType;
  patchedAttachment.thumbnailUrl = newAttachment.thumbnailUrl;
  const patchedAttachments = activity.attachments.map(target => target === attachment ? patchedAttachment : target);
  const patchedActivity = Object.assign({}, activity);
  patchedActivity.attachments = patchedAttachments;
  return {
    activity: patchedActivity,
    attachment: patchedAttachment
  };
};
const genPreviewCardWithAttachment = (card, iconData, next) => {
  const patchedTextCard = patchAttachment(card, {
    contentType: _Constants.MimeTypes.UnknownFileType,
    thumbnailUrl: undefined
  });
  return /*#__PURE__*/_react.default.createElement(_Attachment.default, {
    iconData: iconData,
    imageCard: card,
    textCard: patchedTextCard,
    renderer: next
  });
};
const createAttachmentMiddleware = enableInlinePlaying => {
  // eslint-disable-next-line react/display-name
  const attachmentMiddleware = () => next => function () {
    var _state$domainStates$r, _state$domainStates$r2, _state$domainStates$r3, _card$activity$channe;
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }
    const [card] = args;
    if (!(card !== null && card !== void 0 && card.activity)) {
      return next(...args);
    }
    const {
      activity: {
        attachments
      },
      attachment
    } = card;
    // No attachment
    if (!attachments || !attachments.length || !attachment) {
      return next(...args);
    }

    // Check for Adaptive cards
    // eslint-disable-next-line prefer-const
    let {
      content,
      contentType
    } = attachment || {
      content: "",
      contentType: ""
    };
    let {
      type
    } = content || {
      type: ""
    };
    if (!type && content && _Constants.Constants.supportedAdaptiveCardContentTypes.indexOf(contentType) >= 0) {
      try {
        content = JSON.parse(content);
        type = content.type;
        card.attachment.content = content;
      } catch (e) {
        const errorData = "Unable to parse the adaptive card format";
        _omnichannelChatComponents.BroadcastService.postMessage({
          eventName: _TelemetryConstants.BroadcastEvent.InvalidAdaptiveCardFormat,
          payload: {
            Message: errorData,
            ExceptionDetails: e
          }
        });
      }
    }
    const [state] = (0, _.useChatContextStore)();
    const attachmentId = ((_state$domainStates$r = state.domainStates.renderingMiddlewareProps) === null || _state$domainStates$r === void 0 ? void 0 : (_state$domainStates$r2 = _state$domainStates$r.attachmentProps) === null || _state$domainStates$r2 === void 0 ? void 0 : _state$domainStates$r2.adaptiveCardAttachmentId) ?? _defaultAttachmentProps.defaultAttachmentProps.adaptiveCardAttachmentId;
    const atttachmentAdaptiveCardStyles = {
      ..._defaultAtttachmentAdaptiveCardStyles.defaultAttachmentAdaptiveCardStyles,
      ...((_state$domainStates$r3 = state.domainStates.renderingMiddlewareProps) === null || _state$domainStates$r3 === void 0 ? void 0 : _state$domainStates$r3.attachmentAdaptiveCardStyles)
    };
    if (type === _Constants.WebChatMiddlewareConstants.adaptiveCard || _Constants.Constants.supportedAdaptiveCardContentTypes.indexOf(contentType) >= 0) {
      return /*#__PURE__*/_react.default.createElement("div", {
        id: attachmentId,
        style: atttachmentAdaptiveCardStyles
      }, next(...args));
    } else if (contentType.startsWith(_Constants.Constants.adaptiveCardContentTypePrefix)) {
      console.warn(`${contentType} adaptive card type is currently not supported.`);
    }
    if ((_card$activity$channe = card.activity.channelData) !== null && _card$activity$channe !== void 0 && _card$activity$channe.middlewareData) {
      attachment.contentUrl = card.activity.channelData.middlewareData[attachment.name];
    } else if (attachment !== null && attachment !== void 0 && attachment.tempContentUrl) {
      attachment.contentUrl = attachment.tempContentUrl;
    }
    if (!attachment.name) {
      return next(...args);
    }
    if (card.activity.channelData && card.activity.channelData.fileScan) {
      const index = attachments.findIndex(attachment => attachment.name === card.attachment.name);
      const {
        activity: {
          channelData: {
            fileScan
          }
        }
      } = card;
      const scanResult = fileScan[index];
      if ((scanResult === null || scanResult === void 0 ? void 0 : scanResult.status) === _FileScanStatus.default.INPROGRESS) {
        return /*#__PURE__*/_react.default.createElement(_ScanInProgressAttachment.default, {
          textCard: card
        });
      }
      if ((scanResult === null || scanResult === void 0 ? void 0 : scanResult.status) === _FileScanStatus.default.MALWARE) {
        var _state$domainStates$m;
        const localizedText = ((_state$domainStates$m = state.domainStates.middlewareLocalizedTexts) === null || _state$domainStates$m === void 0 ? void 0 : _state$domainStates$m.MIDDLEWARE_BANNER_FILE_IS_MALICIOUS) ?? _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_FILE_IS_MALICIOUS;
        _NotificationHandler.NotificationHandler.notifyError(_NotificationScenarios.NotificationScenarios.AttachmentError, localizedText.replace("{0}", attachment.name));
        return /*#__PURE__*/_react.default.createElement(_MaliciousAttachment.default, {
          textCard: card
        });
      }
    }
    const fileExtension = attachment.name.substring(attachment.name.lastIndexOf(".") + 1, attachment.name.length) || attachment.name;
    const imageExtension = _Constants.Constants.imageRegex.test(attachment.name);
    const audioExtension = _Constants.Constants.audioMediaRegex.test(attachment.name);
    const videoExtension = _Constants.Constants.videoMediaRegex.test(attachment.name);
    const iconData = (0, _FileAttachmentIconManager.getFileAttachmentIconData)(fileExtension);
    if (imageExtension) {
      return genPreviewCardWithAttachment(card, iconData, next);
    }
    if (audioExtension || videoExtension) {
      if (enableInlinePlaying && card.activity.actionType && card.activity.actionType === _WebChatActionType.WebChatActionType.DIRECT_LINE_INCOMING_ACTIVITY && (0, _FileAttachmentIconManager.isInlineMediaSupported)(attachment.name)) {
        return genPreviewCardWithAttachment(card, iconData, next);
      }
      return /*#__PURE__*/_react.default.createElement(_Attachment.default, {
        iconData: iconData,
        textCard: patchAttachment(card, {
          contentType: _Constants.MimeTypes.UnknownFileType,
          thumbnailUrl: undefined
        }),
        renderer: next
      });
    }
    const isUnknownImageObject = contentType.toLowerCase().includes("image") && !imageExtension;
    if (fileExtension === "txt" || isUnknownImageObject) {
      return /*#__PURE__*/_react.default.createElement(_Attachment.default, {
        iconData: iconData,
        textCard: patchAttachment(card, {
          contentType: _Constants.MimeTypes.UnknownFileType,
          thumbnailUrl: undefined
        }),
        renderer: next
      });
    }
    return /*#__PURE__*/_react.default.createElement(_Attachment.default, {
      iconData: iconData,
      textCard: card,
      renderer: next
    });
  };
  return attachmentMiddleware;
};
exports.createAttachmentMiddleware = createAttachmentMiddleware;