"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NotificationHandler = void 0;
var _Constants = require("../../../../common/Constants");
var _NotificationLevel = require("../enums/NotificationLevel");
var _WebChatActionType = require("../enums/WebChatActionType");
var _WebChatStoreLoader = require("../WebChatStoreLoader");
var _utils = require("../../../../common/utils");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _TelemetryConstants = require("../../../../common/telemetry/TelemetryConstants");
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
let NotificationHandler = /*#__PURE__*/function () {
  function NotificationHandler() {
    _classCallCheck(this, NotificationHandler);
  }
  _createClass(NotificationHandler, null, [{
    key: "notify",
    value: function notify(id, level, message) {
      if (_WebChatStoreLoader.WebChatStoreLoader.store) {
        _WebChatStoreLoader.WebChatStoreLoader.store.dispatch({
          type: _WebChatActionType.WebChatActionType.WEB_CHAT_SET_NOTIFICATION,
          payload: {
            id,
            level,
            message
          }
        });
        NotificationHandler.setFocusOnNotificationCloseButton();
      }
    }
  }, {
    key: "dismissNotification",
    value: function dismissNotification(id) {
      if (_WebChatStoreLoader.WebChatStoreLoader.store) {
        _WebChatStoreLoader.WebChatStoreLoader.store.dispatch({
          type: _WebChatActionType.WebChatActionType.WEB_CHAT_DISMISS_NOTIFICATION,
          payload: {
            id
          }
        });
      }
    }
  }, {
    key: "notifyError",
    value: function notifyError(id, message) {
      _omnichannelChatComponents.BroadcastService.postMessage({
        eventName: _TelemetryConstants.BroadcastEvent.OnWidgetError,
        payload: {
          errorMessage: message
        }
      });
      this.notify(id, _NotificationLevel.NotificationLevel.Error, message);
    }
  }, {
    key: "notifyWarning",
    value: function notifyWarning(id, message) {
      this.notify(id, _NotificationLevel.NotificationLevel.Warning, message);
    }
  }, {
    key: "notifyInfo",
    value: function notifyInfo(id, message) {
      this.notify(id, _NotificationLevel.NotificationLevel.Info, message);
    }
  }, {
    key: "notifySuccess",
    value: function notifySuccess(id, message) {
      this.notify(id, _NotificationLevel.NotificationLevel.Success, message);
    }
  }, {
    key: "notifyWithLevel",
    value: function notifyWithLevel(id, message, level) {
      if (!level) {
        this.notifyInfo(id, message);
      } else {
        this.notify(id, level, message);
      }
    }

    /* Bypass WebChat behavior and focus on banner close button */
  }, {
    key: "setFocusOnNotificationCloseButton",
    value: function setFocusOnNotificationCloseButton() {
      const expandButton = document.querySelector(`#${_Constants.HtmlIdNames.MSLiveChatWidget} .${_Constants.HtmlClassNames.webChatBannerExpandButton}`);
      if (expandButton) {
        expandButton.focus();
        return;
      }
      const closeButton = document.querySelector(`#${_Constants.HtmlIdNames.MSLiveChatWidget} .${_Constants.HtmlClassNames.webChatBannerCloseButton}`);
      if (closeButton) {
        closeButton.focus();
        NotificationHandler.registerOnCloseEvent(closeButton);
        return;
      }
    }
  }, {
    key: "registerOnCloseEvent",
    value: function registerOnCloseEvent(button) {
      button.onclick = () => {
        (0, _utils.setFocusOnSendBox)();
      };
    }
  }]);
  return NotificationHandler;
}();
exports.NotificationHandler = NotificationHandler;