"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLiveChatWidgetContextInitialState = void 0;
var _Constants = require("../../common/Constants");
var _utils = require("../../common/utils");
var _ConversationState = require("./ConversationState");
var _StartChatFailureType = require("./StartChatFailureType");
var _defaultClientDataStoreProvider = require("../../common/storage/default/defaultClientDataStoreProvider");
var _defaultMiddlewareLocalizedTexts = require("../../components/webchatcontainerstateful/common/defaultProps/defaultMiddlewareLocalizedTexts");
const getLiveChatWidgetContextInitialState = props => {
  var _props$controlProps, _props$webChatContain;
  const isOutsideOperatingHours = () => {
    var _props$chatConfig, _props$chatConfig$Liv, _props$chatConfig$Liv2;
    return ((_props$chatConfig = props.chatConfig) === null || _props$chatConfig === void 0 ? void 0 : (_props$chatConfig$Liv = _props$chatConfig.LiveWSAndLiveChatEngJoin) === null || _props$chatConfig$Liv === void 0 ? void 0 : (_props$chatConfig$Liv2 = _props$chatConfig$Liv.OutOfOperatingHours) === null || _props$chatConfig$Liv2 === void 0 ? void 0 : _props$chatConfig$Liv2.toString().toLowerCase()) === "true";
  };
  const widgetCacheId = (0, _utils.getWidgetCacheIdfromProps)(props);
  const cacheTtlInMins = (props === null || props === void 0 ? void 0 : (_props$controlProps = props.controlProps) === null || _props$controlProps === void 0 ? void 0 : _props$controlProps.cacheTtlInMins) ?? _Constants.Constants.CacheTtlInMinutes;
  const storageType = (props === null || props === void 0 ? void 0 : props.useSessionStorage) === true ? _Constants.StorageType.sessionStorage : _Constants.StorageType.localStorage;
  const initialState = (0, _defaultClientDataStoreProvider.defaultClientDataStoreProvider)(cacheTtlInMins, storageType).getData(widgetCacheId);
  if (!(0, _utils.isNullOrUndefined)(initialState)) {
    const initialStateFromCache = JSON.parse(initialState);
    const outsideOperatingHours = isOutsideOperatingHours();

    /*
    * this step is needed to avoid the pre-chat pane to be injected in the DOM when the widget is reloaded, because wont be visible
    * and it will be blocking all elements behind it
    * as part of the flow, the pre-chat will be detected and then it will be displayed properly 
    * this case is only and only for pre-chat pane.
    * **/
    if (initialStateFromCache.appStates.conversationState === _ConversationState.ConversationState.Prechat || initialStateFromCache.appStates.conversationState === _ConversationState.ConversationState.OutOfOffice || outsideOperatingHours) {
      initialStateFromCache.appStates.conversationState = _ConversationState.ConversationState.Closed;
      // if we are resetting the conversation state, there is no point to obtain minimized state from cache
      initialStateFromCache.appStates.isMinimized = undefined;
    }
    // we are always setting the chatConfig from the props to avoid any issues with the cache
    initialStateFromCache.domainStates.liveChatConfig = props.chatConfig;
    // Cache the result of isOutsideOperatingHours() to ensure consistency
    initialStateFromCache.appStates.outsideOperatingHours = outsideOperatingHours;
    return initialStateFromCache;
  }
  const LiveChatWidgetContextInitialState = {
    domainStates: {
      liveChatConfig: props.chatConfig,
      widgetElementId: "",
      renderingMiddlewareProps: (_props$webChatContain = props.webChatContainerProps) === null || _props$webChatContain === void 0 ? void 0 : _props$webChatContain.renderingMiddlewareProps,
      middlewareLocalizedTexts: _defaultMiddlewareLocalizedTexts.defaultMiddlewareLocalizedTexts,
      preChatSurveyResponse: "{}",
      chatToken: undefined,
      postChatContext: undefined,
      telemetryInternalData: {},
      globalDir: "ltr",
      liveChatContext: undefined,
      customContext: undefined,
      widgetSize: undefined,
      widgetInstanceId: "",
      initialChatSdkRequestId: "",
      transcriptRequestId: "",
      confirmationPaneConfirmedOptionClicked: false,
      confirmationState: _Constants.ConfirmationState.NotSet,
      startChatFailureType: _StartChatFailureType.StartChatFailureType.Generic
    },
    appStates: {
      conversationState: _ConversationState.ConversationState.Closed,
      isMinimized: undefined,
      previousElementIdOnFocusBeforeModalOpen: null,
      startChatFailed: false,
      outsideOperatingHours: isOutsideOperatingHours(),
      preChatResponseEmail: "",
      isAudioMuted: null,
      newMessage: false,
      hideStartChatButton: false,
      reconnectId: undefined,
      proactiveChatStates: {
        proactiveChatBodyTitle: "",
        proactiveChatEnablePrechat: false,
        proactiveChatInNewWindow: false
      },
      e2vvEnabled: false,
      unreadMessageCount: 0,
      conversationEndedBy: _Constants.ConversationEndEntity.NotSet,
      chatDisconnectEventReceived: false,
      selectedSurveyMode: null,
      postChatParticipantType: undefined
    },
    uiStates: {
      showConfirmationPane: false,
      showStartChatErrorPane: false,
      showEmailTranscriptPane: false,
      showCallingPopup: false,
      isIncomingCall: true,
      disableVideoCall: true,
      disableRemoteVideo: true,
      disableSelfVideo: true,
      focusChatButton: false
    }
  };
  return LiveChatWidgetContextInitialState;
};
exports.getLiveChatWidgetContextInitialState = getLiveChatWidgetContextInitialState;