"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.polyfillMessagePayloadForEvent = exports.isHistoryMessage = exports.getScenarioType = exports.createTrackingMessage = exports.buildMessagePayload = void 0;
var _Constants = require("./Constants");
var _Constants2 = require("../common/Constants");
const isHistoryMessage = (activity, startTime) => {
  try {
    if ((activity === null || activity === void 0 ? void 0 : activity.type) === _Constants2.Constants.message) {
      var _activity$channelData, _activity$channelData2;
      // this is an old piece of code, probably no longer relevant
      if (activity !== null && activity !== void 0 && (_activity$channelData = activity.channelData) !== null && _activity$channelData !== void 0 && (_activity$channelData2 = _activity$channelData.tags) !== null && _activity$channelData2 !== void 0 && _activity$channelData2.includes(_Constants2.Constants.historyMessageTag)) return true;

      // Id is an epoch time in milliseconds , in utc format, for some reason is in a string format
      if (activity !== null && activity !== void 0 && activity.id) {
        /// activity.id is an string that contains epoch time in milliseconds
        const activityId = parseInt(activity === null || activity === void 0 ? void 0 : activity.id);

        // if the activity id is not a number, we default to new message
        if (isNaN(activityId)) {
          return false;
        }

        // if the activity id is less than the start time, it means that the message is a history message
        if (activityId < startTime) {
          return true;
        }
      }
      // anything else will be considered a new message
      return false;
    }
  } catch (e) {
    // if there is an error in parsing the activity id, we will consider it a new message
    console.error("Error in parsing activity id: ", e);
  }
  return false;
};
exports.isHistoryMessage = isHistoryMessage;
const buildMessagePayload = (activity, userId) => {
  var _text, _text2, _activity$channelData3, _activity$from;
  return {
    // To identify hidden contents vs empty content
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    text: (activity === null || activity === void 0 ? void 0 : (_text = activity.text) === null || _text === void 0 ? void 0 : _text.length) >= 1 ? `*contents hidden (${activity === null || activity === void 0 ? void 0 : (_text2 = activity.text) === null || _text2 === void 0 ? void 0 : _text2.length} chars)*` : "",
    type: activity === null || activity === void 0 ? void 0 : activity.type,
    timestamp: activity === null || activity === void 0 ? void 0 : activity.timestamp,
    userId: userId,
    tags: activity === null || activity === void 0 ? void 0 : (_activity$channelData3 = activity.channelData) === null || _activity$channelData3 === void 0 ? void 0 : _activity$channelData3.tags,
    messageType: "",
    Id: activity === null || activity === void 0 ? void 0 : activity.id,
    role: activity === null || activity === void 0 ? void 0 : (_activity$from = activity.from) === null || _activity$from === void 0 ? void 0 : _activity$from.role,
    isChatComplete: false
  };
};
exports.buildMessagePayload = buildMessagePayload;
const polyfillMessagePayloadForEvent = (activity, payload, conversationId) => {
  var _activity$conversatio, _attachments, _activity$from2;
  return {
    ...payload,
    channelData: activity === null || activity === void 0 ? void 0 : activity.channelData,
    chatId: activity === null || activity === void 0 ? void 0 : (_activity$conversatio = activity.conversation) === null || _activity$conversatio === void 0 ? void 0 : _activity$conversatio.id,
    conversationId: conversationId,
    Id: activity === null || activity === void 0 ? void 0 : activity.id,
    isChatComplete: false,
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    text: activity === null || activity === void 0 ? void 0 : activity.text,
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    attachment: (activity === null || activity === void 0 ? void 0 : (_attachments = activity.attachments) === null || _attachments === void 0 ? void 0 : _attachments.length) >= 1 ? activity === null || activity === void 0 ? void 0 : activity.attachments : [],
    role: activity === null || activity === void 0 ? void 0 : (_activity$from2 = activity.from) === null || _activity$from2 === void 0 ? void 0 : _activity$from2.role
  };
};
exports.polyfillMessagePayloadForEvent = polyfillMessagePayloadForEvent;
const getScenarioType = activity => {
  var _activity$from3, _activity$channelData4;
  const role = activity === null || activity === void 0 ? void 0 : (_activity$from3 = activity.from) === null || _activity$from3 === void 0 ? void 0 : _activity$from3.role;
  const tags = activity === null || activity === void 0 ? void 0 : (_activity$channelData4 = activity.channelData) === null || _activity$channelData4 === void 0 ? void 0 : _activity$channelData4.tags;
  if (role === _Constants2.Constants.userMessageTag) {
    return _Constants.ScenarioType.UserSendMessageStrategy;
  }
  if (tags && tags.includes(_Constants2.Constants.systemMessageTag) || role === _Constants2.Constants.channelMessageTag) {
    return _Constants.ScenarioType.SystemMessageStrategy;
  }
  return _Constants.ScenarioType.ReceivedMessageStrategy;
};
exports.getScenarioType = getScenarioType;
const createTrackingMessage = (payload, type) => {
  return {
    Id: payload.Id,
    role: payload.role,
    timestamp: payload === null || payload === void 0 ? void 0 : payload.timestamp,
    tags: payload.tags,
    messageType: payload.messageType,
    text: payload.text,
    type: type,
    checkTime: new Date().getTime()
  };
};
exports.createTrackingMessage = createTrackingMessage;