"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createOnNewAdapterActivityHandler = void 0;
var _TelemetryConstants = require("../common/telemetry/TelemetryConstants");
var _Constants = require("../firstresponselatency/Constants");
var _util = require("../firstresponselatency/util");
var _omnichannelChatComponents = require("@microsoft/omnichannel-chat-components");
var _Constants2 = require("../common/Constants");
var _FirstResponseLatencyTracker = require("../firstresponselatency/FirstResponseLatencyTracker");
var _TelemetryHelper = require("../common/telemetry/TelemetryHelper");
var _TelemetryManager = require("../common/telemetry/TelemetryManager");
const createOnNewAdapterActivityHandler = (chatId, userId) => {
  // Hooking the message tracker in the listener, a bit invasive but easier to control.
  const firstResponseLatencyTracker = new _FirstResponseLatencyTracker.FirstResponseLatencyTracker();
  // epoch time in utc for when start to listen.
  // We dont longer have a mechanism to know if a message is history or new, so any message older than the time we start listening will be considered a history message.
  // this is a workaround for the fact that we dont have a way to identify if a message is history or new, and it will provide consistency across different scenarios
  const startTime = new Date().getTime();
  let isHistoryMessageReceivedEventRaised = false;
  const onNewAdapterActivityHandler = activity => {
    raiseMessageEvent(activity);
  };
  const userSendMessageStrategy = activity => {
    var _TelemetryManager$Int;
    const payload = (0, _util.buildMessagePayload)(activity, userId);
    payload.messageType = _Constants2.Constants.userMessageTag;
    const newMessageSentEvent = {
      eventName: _TelemetryConstants.BroadcastEvent.NewMessageSent,
      payload: (0, _util.polyfillMessagePayloadForEvent)(activity, payload, (_TelemetryManager$Int = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int === void 0 ? void 0 : _TelemetryManager$Int.conversationId)
    };
    _omnichannelChatComponents.BroadcastService.postMessage(newMessageSentEvent);
    if (!(0, _util.isHistoryMessage)(activity, startTime)) {
      firstResponseLatencyTracker.startClock(payload);
    }
    _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.MessageSent,
      Description: "New message sent"
    });
  };
  const systemMessageStrategy = activity => {
    const payload = (0, _util.buildMessagePayload)(activity, userId);
    payload.messageType = _Constants2.Constants.systemMessageTag;
    if ((0, _util.isHistoryMessage)(activity, startTime)) {
      var _TelemetryManager$Int2;
      historyMessageStrategy((0, _util.polyfillMessagePayloadForEvent)(activity, payload, (_TelemetryManager$Int2 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int2 === void 0 ? void 0 : _TelemetryManager$Int2.conversationId));
      return;
    }
    _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.SystemMessageReceived,
      Description: "System message received"
    });
  };
  const historyMessageStrategy = payload => {
    const newMessageReceivedEvent = {
      eventName: _TelemetryConstants.BroadcastEvent.HistoryMessageReceived,
      payload: payload
    };
    _omnichannelChatComponents.BroadcastService.postMessage(newMessageReceivedEvent);
    if (!isHistoryMessageReceivedEventRaised) {
      // this is needed for reload scenarios, it helps to identify the last message received before the reload
      isHistoryMessageReceivedEventRaised = true;
      _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
        Event: _TelemetryConstants.TelemetryEvent.RehydrateMessageReceived,
        Description: "History message received",
        CustomProperties: payload
      });
    }
  };
  const isValidMessage = activity => {
    var _activity$channelData, _activity$channelData2, _activity$channelData3;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const messageHasNoText = !(activity !== null && activity !== void 0 && activity.text);
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const messageHasNoTags = !(activity !== null && activity !== void 0 && activity.channelData) || !(activity !== null && activity !== void 0 && (_activity$channelData = activity.channelData) !== null && _activity$channelData !== void 0 && _activity$channelData.tags) || (activity === null || activity === void 0 ? void 0 : (_activity$channelData2 = activity.channelData) === null || _activity$channelData2 === void 0 ? void 0 : (_activity$channelData3 = _activity$channelData2.tags) === null || _activity$channelData3 === void 0 ? void 0 : _activity$channelData3.length) === 0;
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const messageHasNoAttachments = !(activity !== null && activity !== void 0 && activity.attachments) || (activity === null || activity === void 0 ? void 0 : activity.attachments.length) === 0;
    if (messageHasNoTags && messageHasNoText && messageHasNoAttachments) {
      return false;
    }
    return true;
  };
  const receivedMessageStrategy = activity => {
    var _TelemetryManager$Int4;
    if (!isValidMessage(activity)) return;
    const isHistoryMessageReceived = (0, _util.isHistoryMessage)(activity, startTime);
    const payload = (0, _util.buildMessagePayload)(activity, userId);
    payload.messageType = _Constants2.Constants.userMessageTag;
    if (isHistoryMessageReceived) {
      var _TelemetryManager$Int3;
      historyMessageStrategy((0, _util.polyfillMessagePayloadForEvent)(activity, payload, (_TelemetryManager$Int3 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int3 === void 0 ? void 0 : _TelemetryManager$Int3.conversationId));
      return;
    }
    firstResponseLatencyTracker.stopClock(payload);
    const newMessageReceivedEvent = {
      eventName: _TelemetryConstants.BroadcastEvent.NewMessageReceived,
      payload: (0, _util.polyfillMessagePayloadForEvent)(activity, payload, (_TelemetryManager$Int4 = _TelemetryManager.TelemetryManager.InternalTelemetryData) === null || _TelemetryManager$Int4 === void 0 ? void 0 : _TelemetryManager$Int4.conversationId)
    };
    _omnichannelChatComponents.BroadcastService.postMessage(newMessageReceivedEvent);
    _TelemetryHelper.TelemetryHelper.logActionEventToAllTelemetry(_TelemetryConstants.LogLevel.INFO, {
      Event: _TelemetryConstants.TelemetryEvent.MessageReceived,
      Description: "New message received",
      CustomProperties: payload
    });
  };
  const raiseMessageEvent = activity => {
    if ((activity === null || activity === void 0 ? void 0 : activity.type) === _Constants2.Constants.message) {
      const scenarioType = (0, _util.getScenarioType)(activity);
      switch (scenarioType) {
        case _Constants.ScenarioType.UserSendMessageStrategy:
          userSendMessageStrategy(activity);
          break;
        case _Constants.ScenarioType.SystemMessageStrategy:
          systemMessageStrategy(activity);
          break;
        case _Constants.ScenarioType.ReceivedMessageStrategy:
          receivedMessageStrategy(activity);
          break;
      }
    }
  };
  return onNewAdapterActivityHandler;
};
exports.createOnNewAdapterActivityHandler = createOnNewAdapterActivityHandler;