import { LogLevel, TelemetryEvent } from "../../../common/telemetry/TelemetryConstants";
import { TelemetryHelper } from "../../../common/telemetry/TelemetryHelper";
import { WidgetLoadCustomErrorString } from "../../../common/Constants";
import { isNullOrEmptyString } from "../../../common/utils";
const getAuthClientFunction = chatConfig => {
  let authClientFunction = undefined;
  if (chatConfig !== null && chatConfig !== void 0 && chatConfig.LiveChatConfigAuthSettings) {
    var _chatConfig$LiveChatC;
    authClientFunction = (chatConfig === null || chatConfig === void 0 ? void 0 : (_chatConfig$LiveChatC = chatConfig.LiveChatConfigAuthSettings) === null || _chatConfig$LiveChatC === void 0 ? void 0 : _chatConfig$LiveChatC.msdyn_javascriptclientfunction) ?? undefined;
  }
  return authClientFunction;
};
const handleAuthentication = async (chatSDK, chatConfig, getAuthToken) => {
  var _chatSDK$chatSDKConfi;
  const authClientFunction = getAuthClientFunction(chatConfig);
  if (getAuthToken && authClientFunction) {
    TelemetryHelper.logActionEvent(LogLevel.INFO, {
      Event: TelemetryEvent.GetAuthTokenCalled
    });
    const token = await getAuthToken(authClientFunction);
    if (!isNullOrEmptyString(token)) {
      // eslint-disable-next-line @typescript-eslint/no-explicit-any
      chatSDK.setAuthTokenProvider(async () => {
        return token;
      });
      return {
        "result": true,
        "token": token
      };
    } else {
      // instead of returning false, it's more appropiate to thrown an error to force error handling on the caller side
      // this will help to avoid the error to be ignored and the chat to be started
      TelemetryHelper.logActionEvent(LogLevel.ERROR, {
        Event: TelemetryEvent.ReceivedNullOrEmptyToken
      });
      throw new Error(WidgetLoadCustomErrorString.AuthenticationFailedErrorString);
    }
  } else if (chatSDK !== null && chatSDK !== void 0 && (_chatSDK$chatSDKConfi = chatSDK.chatSDKConfig) !== null && _chatSDK$chatSDKConfi !== void 0 && _chatSDK$chatSDKConfi.getAuthToken) {
    var _chatSDK$chatSDKConfi2;
    const token = await ((_chatSDK$chatSDKConfi2 = chatSDK.chatSDKConfig) === null || _chatSDK$chatSDKConfi2 === void 0 ? void 0 : _chatSDK$chatSDKConfi2.getAuthToken());
    if (isNullOrEmptyString(token)) {
      TelemetryHelper.logActionEvent(LogLevel.ERROR, {
        Event: TelemetryEvent.ReceivedNullOrEmptyToken,
        Description: "getAuthToken in chat SDK returns empty string"
      });
      throw new Error(WidgetLoadCustomErrorString.AuthenticationFailedErrorString);
    }
    return {
      "result": true,
      token
    };
  }
  return {
    "result": false,
    "token": null,
    "error": {
      "message": "No auth client function or getAuthToken function provided",
      "getAuthTokenPresent": getAuthToken ? true : false,
      "authClientFunctionPresent": authClientFunction ? true : false
    }
  };
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const removeAuthTokenProvider = chatSDK => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.authenticatedUserToken = null;
};
export { getAuthClientFunction, handleAuthentication, removeAuthTokenProvider };