import { BroadcastEvent, LogLevel, TelemetryEvent } from "../../../common/telemetry/TelemetryConstants";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { Constants } from "../../../common/Constants";
import { NotificationHandler } from "../../webchatcontainerstateful/webchatcontroller/notification/NotificationHandler";
import { NotificationScenarios } from "../../webchatcontainerstateful/webchatcontroller/enums/NotificationScenarios";
import { TelemetryHelper } from "../../../common/telemetry/TelemetryHelper";
import { defaultMiddlewareLocalizedTexts } from "../../webchatcontainerstateful/common/defaultProps/defaultMiddlewareLocalizedTexts";
import { executeReducer } from "../../../contexts/createReducer";
import { LiveChatWidgetActionType } from "../../../contexts/common/LiveChatWidgetActionType";
const isInternetConnected = async () => {
  try {
    const response = await fetch(Constants.internetConnectionTestUrl);
    const text = await response.text();
    return text === Constants.internetConnectionTestUrlText;
  } catch {
    return false;
  }
};
export const createInternetConnectionChangeHandler = async state => {
  const handler = async () => {
    const connected = await isInternetConnected();
    const inMemoryState = executeReducer(state, {
      type: LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: null
    });
    if (!connected) {
      var _inMemoryState$domain, _inMemoryState$domain2;
      TelemetryHelper.logActionEvent(LogLevel.WARN, {
        Event: TelemetryEvent.NetworkDisconnected
      });
      NotificationHandler.notifyError(NotificationScenarios.InternetConnection, (inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$domain = inMemoryState.domainStates) === null || _inMemoryState$domain === void 0 ? void 0 : (_inMemoryState$domain2 = _inMemoryState$domain.middlewareLocalizedTexts) === null || _inMemoryState$domain2 === void 0 ? void 0 : _inMemoryState$domain2.MIDDLEWARE_BANNER_NO_INTERNET_CONNECTION) ?? defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_NO_INTERNET_CONNECTION);
    } else {
      var _inMemoryState$domain3, _inMemoryState$domain4;
      TelemetryHelper.logActionEvent(LogLevel.WARN, {
        Event: TelemetryEvent.NetworkReconnected
      });
      NotificationHandler.notifySuccess(NotificationScenarios.InternetConnection, (inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$domain3 = inMemoryState.domainStates) === null || _inMemoryState$domain3 === void 0 ? void 0 : (_inMemoryState$domain4 = _inMemoryState$domain3.middlewareLocalizedTexts) === null || _inMemoryState$domain4 === void 0 ? void 0 : _inMemoryState$domain4.MIDDLEWARE_BANNER_INTERNET_BACK_ONLINE) ?? defaultMiddlewareLocalizedTexts.MIDDLEWARE_BANNER_INTERNET_BACK_ONLINE);
      BroadcastService.postMessage({
        eventName: BroadcastEvent.NetworkReconnected
      });
    }
  };

  // Checking connection status on online & offline events due to possible false positives
  window.addEventListener("online", () => handler(), false);
  window.addEventListener("offline", () => handler(), false);
};