import { BroadcastEvent, LogLevel, TelemetryEvent } from "../../../common/telemetry/TelemetryConstants";
import { ConfirmationState, Constants, ConversationEndEntity, ParticipantType, PrepareEndChatDescriptionConstants } from "../../../common/Constants";
import { getConversationDetailsCall, getWidgetEndChatEventName } from "../../../common/utils";
import { getPostChatContext, initiatePostChat } from "./renderSurveyHelpers";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { ConversationState } from "../../../contexts/common/ConversationState";
import { LiveChatWidgetActionType } from "../../../contexts/common/LiveChatWidgetActionType";
import { TelemetryHelper } from "../../../common/telemetry/TelemetryHelper";
import { TelemetryManager } from "../../../common/telemetry/TelemetryManager";
import { WebChatStoreLoader } from "../../webchatcontainerstateful/webchatcontroller/WebChatStoreLoader";
import { defaultWebChatContainerStatefulProps } from "../../webchatcontainerstateful/common/defaultProps/defaultWebChatContainerStatefulProps";
import { executeReducer } from "../../../contexts/createReducer";
import { isPersistentEnabled } from "./reconnectChatHelper";
import { uuidv4 } from "@microsoft/omnichannel-chat-sdk";

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const prepareEndChat = async (props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter) => {
  try {
    var _conversationDetails$, _state$domainStates, _state$appStates3;
    const {
      chatConfig
    } = props;

    // Use Case: If call is ongoing, end the call by simulating end call button click
    endVoiceVideoCallIfOngoing(facadeChatSDK, dispatch);
    const conversationDetails = await getConversationDetailsCall(facadeChatSDK);

    // Use Case: When post chat is not configured
    if ((conversationDetails === null || conversationDetails === void 0 ? void 0 : (_conversationDetails$ = conversationDetails.canRenderPostChat) === null || _conversationDetails$ === void 0 ? void 0 : _conversationDetails$.toLowerCase()) === Constants.false) {
      var _state$appStates;
      // If ended by customer, just close chat
      if ((state === null || state === void 0 ? void 0 : (_state$appStates = state.appStates) === null || _state$appStates === void 0 ? void 0 : _state$appStates.conversationEndedBy) === ConversationEndEntity.Customer) {
        TelemetryHelper.logSDKEvent(LogLevel.INFO, {
          Event: TelemetryEvent.PrepareEndChat,
          Description: PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithoutPostChat
        });
        await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
      }

      // Use Case: If ended by Agent, stay chat in InActive state
      return;
    }

    // Register post chat participant type
    if ((conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType) === ParticipantType.Bot || (conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType) === ParticipantType.User) {
      dispatch({
        type: LiveChatWidgetActionType.SET_POST_CHAT_PARTICIPANT_TYPE,
        payload: conversationDetails === null || conversationDetails === void 0 ? void 0 : conversationDetails.participantType
      });
    }

    // Use Case: Can render post chat scenarios
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const postchatContext = (await getPostChatContext(facadeChatSDK, state, dispatch)) ?? (state === null || state === void 0 ? void 0 : (_state$domainStates = state.domainStates) === null || _state$domainStates === void 0 ? void 0 : _state$domainStates.postChatContext);
    if (postchatContext === undefined) {
      var _state$appStates2;
      BroadcastService.postMessage({
        eventName: BroadcastEvent.OnWidgetError,
        payload: {
          errorMessage: "Widget did not display post chat survey as getPostChatContext returned undefined."
        }
      });

      // For Customer intiated conversations, just close chat widget
      if ((state === null || state === void 0 ? void 0 : (_state$appStates2 = state.appStates) === null || _state$appStates2 === void 0 ? void 0 : _state$appStates2.conversationEndedBy) === ConversationEndEntity.Customer) {
        TelemetryHelper.logSDKEvent(LogLevel.INFO, {
          Event: TelemetryEvent.PrepareEndChat,
          Description: PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithInvalidPostChat
        });
        await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
        return;
      }

      //For agent initiated end chat, allow to download transcript
      dispatch({
        type: LiveChatWidgetActionType.SET_CONVERSATION_STATE,
        payload: ConversationState.InActive
      });
      return;
    }

    // Log PrepareEndChat if conversation ended by customer (bot and agent cases are handled in LiveChatWidgetStateful.tsx)
    if (state !== null && state !== void 0 && (_state$appStates3 = state.appStates) !== null && _state$appStates3 !== void 0 && _state$appStates3.conversationEndedBy) {
      var _state$appStates4;
      TelemetryHelper.logSDKEvent(LogLevel.INFO, {
        Event: TelemetryEvent.PrepareEndChat,
        Description: `${PrepareEndChatDescriptionConstants.ConversationEndedByCustomerWithInvalidPostChat} ${state === null || state === void 0 ? void 0 : (_state$appStates4 = state.appStates) === null || _state$appStates4 === void 0 ? void 0 : _state$appStates4.conversationEndedBy}.`
      });
    }
    const persistentEnabled = isPersistentEnabled(chatConfig);
    const {
      appStates
    } = executeReducer(state, {
      type: LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: undefined
    });
    const endedByCustomer = (appStates === null || appStates === void 0 ? void 0 : appStates.conversationEndedBy) === "Customer";

    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const commonParams = [props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter];
    if (persistentEnabled && endedByCustomer) {
      await endChat(...commonParams, true, false, true);
    } else {
      await endChat(...commonParams, false, true, true);
      if (postchatContext) {
        await initiatePostChat(props, conversationDetails, state, dispatch, postchatContext);
        return;
      }
    }
  } catch (error) {
    var _props$controlProps;
    TelemetryHelper.logActionEvent(LogLevel.ERROR, {
      Event: TelemetryEvent.EndChatFailed,
      ExceptionDetails: {
        exception: JSON.stringify(error)
      }
    });

    //Close chat widget for any failure in embedded to allow to show start chat button
    if (((_props$controlProps = props.controlProps) === null || _props$controlProps === void 0 ? void 0 : _props$controlProps.hideStartChatButton) === false) {
      TelemetryHelper.logSDKEvent(LogLevel.INFO, {
        Event: TelemetryEvent.PrepareEndChat,
        Description: PrepareEndChatDescriptionConstants.PrepareEndChatError
      });
      await endChat(props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, false, false, true);
    }
  } finally {
    //Chat token clean up
    await chatTokenCleanUp(dispatch);
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const endChat = async (props, facadeChatSDK, state, dispatch, setAdapter, setWebChatStyles, adapter, skipEndChatSDK, skipCloseChat, postMessageToOtherTab) => {
  var _facadeChatSDK$getCha;
  if (!skipEndChatSDK && facadeChatSDK !== null && facadeChatSDK !== void 0 && (_facadeChatSDK$getCha = facadeChatSDK.getChatSDK()) !== null && _facadeChatSDK$getCha !== void 0 && _facadeChatSDK$getCha.conversation) {
    var _inMemoryState$appSta;
    const inMemoryState = executeReducer(state, {
      type: LiveChatWidgetActionType.GET_IN_MEMORY_STATE,
      payload: null
    });
    const endChatOptionalParameters = {
      isSessionEnded: inMemoryState === null || inMemoryState === void 0 ? void 0 : (_inMemoryState$appSta = inMemoryState.appStates) === null || _inMemoryState$appSta === void 0 ? void 0 : _inMemoryState$appSta.chatDisconnectEventReceived
    };
    try {
      TelemetryHelper.logSDKEvent(LogLevel.INFO, {
        Event: TelemetryEvent.EndChatSDKCall
      });
      await (facadeChatSDK === null || facadeChatSDK === void 0 ? void 0 : facadeChatSDK.endChat(endChatOptionalParameters));
    } catch (ex) {
      var _inMemoryState$appSta2;
      // if the chat was disconnected or ended by the agent, we don't want to log the error
      if (!(inMemoryState !== null && inMemoryState !== void 0 && (_inMemoryState$appSta2 = inMemoryState.appStates) !== null && _inMemoryState$appSta2 !== void 0 && _inMemoryState$appSta2.chatDisconnectEventReceived)) {
        TelemetryHelper.logSDKEvent(LogLevel.ERROR, {
          Event: TelemetryEvent.EndChatSDKCallFailed,
          ExceptionDetails: {
            exception: ex
          }
        });
      } else {
        TelemetryHelper.logSDKEvent(LogLevel.WARN, {
          Event: TelemetryEvent.DisconnectEndChatSDKCallFailed,
          ExceptionDetails: {
            exception: ex
          }
        });
      }
      postMessageToOtherTab = false;
    } finally {
      endChatStateCleanUp(dispatch);
      facadeChatSDK.destroy();
    }
  }
  if (!skipCloseChat) {
    try {
      var _props$webChatContain;
      adapter === null || adapter === void 0 ? void 0 : adapter.end();
      setAdapter(undefined);
      setWebChatStyles({
        ...defaultWebChatContainerStatefulProps.webChatStyles,
        ...((_props$webChatContain = props.webChatContainerProps) === null || _props$webChatContain === void 0 ? void 0 : _props$webChatContain.webChatStyles)
      });
      WebChatStoreLoader.store = null;
      closeChatStateCleanUp(dispatch);
      TelemetryHelper.logActionEvent(LogLevel.INFO, {
        Event: TelemetryEvent.CloseChatCall,
        Description: "Chat was closed succesfully"
      });
    } catch (error) {
      TelemetryHelper.logActionEvent(LogLevel.ERROR, {
        Event: TelemetryEvent.CloseChatMethodException,
        ExceptionDetails: {
          exception: `Failed to endChat: ${error}`
        }
      });
    } finally {
      dispatch({
        type: LiveChatWidgetActionType.SET_UNREAD_MESSAGE_COUNT,
        payload: 0
      });
      dispatch({
        type: LiveChatWidgetActionType.SET_POST_CHAT_CONTEXT,
        payload: undefined
      });
      // Always allow to close the chat for embedded mode irrespective of end chat errors
      closeChatWidget(dispatch);
      facadeChatSDK.destroy();
    }
  }
  if (postMessageToOtherTab) {
    const endChatEventName = await getEndChatEventName(facadeChatSDK, props);
    BroadcastService.postMessage({
      eventName: endChatEventName,
      payload: {
        runtimeId: TelemetryManager.InternalTelemetryData.lcwRuntimeId
      }
    });
  }
};
export const callingStateCleanUp = dispatch => {
  dispatch({
    type: LiveChatWidgetActionType.SHOW_CALLING_CONTAINER,
    payload: false
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_INCOMING_CALL,
    payload: true
  });
  dispatch({
    type: LiveChatWidgetActionType.DISABLE_VIDEO_CALL,
    payload: true
  });
  dispatch({
    type: LiveChatWidgetActionType.DISABLE_LOCAL_VIDEO,
    payload: true
  });
  dispatch({
    type: LiveChatWidgetActionType.DISABLE_REMOTE_VIDEO,
    payload: true
  });
};
export const endChatStateCleanUp = dispatch => {
  // Need to clear these states immediately when chat ended from OC.
  dispatch({
    type: LiveChatWidgetActionType.SET_RECONNECT_ID,
    payload: undefined
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_CHAT_DISCONNECT_EVENT_RECEIVED,
    payload: false
  });
};
export const closeChatStateCleanUp = dispatch => {
  dispatch({
    type: LiveChatWidgetActionType.SET_CHAT_TOKEN,
    payload: undefined
  });
  // dispatch({ type: LiveChatWidgetActionType.SET_CONVERSATION_STATE, payload: ConversationState.Closed });
  dispatch({
    type: LiveChatWidgetActionType.SET_RECONNECT_ID,
    payload: undefined
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_AUDIO_NOTIFICATION,
    payload: null
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_CONVERSATION_ENDED_BY,
    payload: ConversationEndEntity.NotSet
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_CONFIRMATION_STATE,
    payload: ConfirmationState.NotSet
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_START_CHAT_FAILING,
    payload: false
  });
  dispatch({
    type: LiveChatWidgetActionType.SET_PROACTIVE_CHAT_PARAMS,
    payload: {
      proactiveChatBodyTitle: "",
      proactiveChatEnablePrechat: false,
      proactiveChatInNewWindow: false
    }
  });

  // Clear live chat context only if chat widget is fully closed to support transcript calls after sessionclose is called
  dispatch({
    type: LiveChatWidgetActionType.SET_LIVE_CHAT_CONTEXT,
    payload: undefined
  });
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const chatSDKStateCleanUp = chatSDK => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.requestId = uuidv4();
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.chatToken = {};
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  chatSDK.reconnectId = null;
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const endVoiceVideoCallIfOngoing = async (facadeChatSDK, dispatch) => {
  let callId = "";
  try {
    if (facadeChatSDK.getChatSDK().isVoiceVideoCallingEnabled()) {
      const voiceVideoCallingSdk = await facadeChatSDK.getVoiceVideoCalling();
      if (voiceVideoCallingSdk && voiceVideoCallingSdk.isInACall()) {
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        callId = voiceVideoCallingSdk.callId;
        voiceVideoCallingSdk.stopCall();
        TelemetryHelper.logCallingEvent(LogLevel.INFO, {
          Event: TelemetryEvent.EndCallButtonClick
        }, callId);
        callingStateCleanUp(dispatch);
      }
    }
  } catch (error) {
    TelemetryHelper.logCallingEvent(LogLevel.ERROR, {
      Event: TelemetryEvent.EndCallButtonClickException,
      ExceptionDetails: {
        exception: `Failed to End Call:  ${error}`
      }
    }, callId);
  }
};
const closeChatWidget = dispatch => {
  // Embedded chat
  dispatch({
    type: LiveChatWidgetActionType.SET_CONVERSATION_STATE,
    payload: ConversationState.Closed
  });
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const chatTokenCleanUp = async dispatch => {
  //Just do cleanup here
  dispatch({
    type: LiveChatWidgetActionType.SET_CHAT_TOKEN,
    payload: undefined
  });

  // Need to keep liveChatContext until chat is fully closed to for transcript download/email
};

const getEndChatEventName = async (facadeChatSDK, props) => {
  var _facadeChatSDK$getCha2, _facadeChatSDK$getCha3, _facadeChatSDK$getCha4, _facadeChatSDK$getCha5, _props$controlProps2;
  return getWidgetEndChatEventName((_facadeChatSDK$getCha2 = facadeChatSDK.getChatSDK()) === null || _facadeChatSDK$getCha2 === void 0 ? void 0 : (_facadeChatSDK$getCha3 = _facadeChatSDK$getCha2.omnichannelConfig) === null || _facadeChatSDK$getCha3 === void 0 ? void 0 : _facadeChatSDK$getCha3.orgId, (_facadeChatSDK$getCha4 = facadeChatSDK.getChatSDK()) === null || _facadeChatSDK$getCha4 === void 0 ? void 0 : (_facadeChatSDK$getCha5 = _facadeChatSDK$getCha4.omnichannelConfig) === null || _facadeChatSDK$getCha5 === void 0 ? void 0 : _facadeChatSDK$getCha5.widgetId, (props === null || props === void 0 ? void 0 : (_props$controlProps2 = props.controlProps) === null || _props$controlProps2 === void 0 ? void 0 : _props$controlProps2.widgetInstanceId) ?? "");
};
export { prepareEndChat, endChat };