import { LogLevel, TelemetryEvent } from "../../../common/telemetry/TelemetryConstants";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { ConversationState } from "../../../contexts/common/ConversationState";
import { LiveChatWidgetActionType } from "../../../contexts/common/LiveChatWidgetActionType";
import { PostChatSurveyTelemetryMessage } from "../../../common/Constants";
import { TelemetryHelper } from "../../../common/telemetry/TelemetryHelper";
import { isPostChatSurveyEnabled } from "./liveChatConfigUtils";

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const setPostChatContextAndLoadSurvey = async (facadeChatSDK, dispatch, persistedChat) => {
  try {
    const postChatEnabled = await isPostChatSurveyEnabled(facadeChatSDK);
    if (postChatEnabled) {
      if (!persistedChat) {
        TelemetryHelper.logSDKEventToAllTelemetry(LogLevel.INFO, {
          Event: TelemetryEvent.PostChatContextCallStarted,
          Description: PostChatSurveyTelemetryMessage.PostChatContextCallStarted
        });
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        const context = await facadeChatSDK.getPostChatSurveyContext();
        TelemetryHelper.logSDKEventToAllTelemetry(LogLevel.INFO, {
          Event: TelemetryEvent.PostChatContextCallSucceed,
          Description: PostChatSurveyTelemetryMessage.PostChatContextCallSucceed
        });
        dispatch({
          type: LiveChatWidgetActionType.SET_POST_CHAT_CONTEXT,
          payload: context
        });
      }
    }
  } catch (ex) {
    TelemetryHelper.logSDKEventToAllTelemetry(LogLevel.ERROR, {
      Event: TelemetryEvent.PostChatContextCallFailed,
      Description: PostChatSurveyTelemetryMessage.PostChatContextCallFailed,
      ExceptionDetails: {
        exception: ex
      }
    });
  }
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  BroadcastService.getMessageByEventName("LoadPostChatSurvey").subscribe(msg => {
    dispatch({
      type: LiveChatWidgetActionType.SET_CONVERSATION_STATE,
      payload: ConversationState.Postchat
    });
  });
};