import { BroadcastEvent } from "../../../common/telemetry/TelemetryConstants";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { LiveChatWidgetActionType } from "../../../contexts/common/LiveChatWidgetActionType";
import { TelemetryHelper } from "../../../common/telemetry/TelemetryHelper";
import { TelemetryManager } from "../../../common/telemetry/TelemetryManager";
import { getConversationDetailsCall } from "../../../common/utils";

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const updateTelemetryData = async (facadeChatSDK, dispatch) => {
  // load it concurrently, this will reduce the load time
  await Promise.all([updateSessionDataForTelemetry(facadeChatSDK, dispatch), updateConversationDataForTelemetry(facadeChatSDK, dispatch)]);
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const updateSessionDataForTelemetry = async (facadeChatSDK, dispatch) => {
  if (facadeChatSDK && facadeChatSDK.getChatSDK()) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const chatSession = await facadeChatSDK.getCurrentLiveChatContext();
    const telemetryData = TelemetryHelper.addSessionDataToTelemetry(chatSession, TelemetryManager.InternalTelemetryData);
    dispatch({
      type: LiveChatWidgetActionType.SET_TELEMETRY_DATA,
      payload: telemetryData
    });
    BroadcastService.postMessage({
      eventName: BroadcastEvent.UpdateSessionDataForTelemetry,
      payload: {
        chatSession
      }
    });
  }
};

// eslint-disable-next-line @typescript-eslint/no-explicit-any
const updateConversationDataForTelemetry = async (facadeChatSDK, dispatch) => {
  if (facadeChatSDK && facadeChatSDK.getChatSDK()) {
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    const liveWorkItem = await getConversationDetailsCall(facadeChatSDK);
    const telemetryData = TelemetryHelper.addConversationDataToTelemetry(liveWorkItem, TelemetryManager.InternalTelemetryData);
    dispatch({
      type: LiveChatWidgetActionType.SET_TELEMETRY_DATA,
      payload: telemetryData
    });
    BroadcastService.postMessage({
      eventName: BroadcastEvent.UpdateConversationDataForTelemetry,
      payload: {
        liveWorkItem
      }
    });
  }
};