import { LogLevel, TelemetryEvent } from "../../common/telemetry/TelemetryConstants";
import React, { useEffect } from "react";
import { createTimer, findAllFocusableElement } from "../../common/utils";
import { OutOfOfficeHoursPane } from "@microsoft/omnichannel-chat-components";
import { TelemetryHelper } from "../../common/telemetry/TelemetryHelper";
import { defaultGeneralStyleProps } from "./common/defaultStyleProps/defaultgeneralOOOHPaneStyleProps";
import { detectAndCleanXSS } from "../../common/utils/xssUtils";
import useChatContextStore from "../../hooks/useChatContextStore";
let uiTimer;
const OOOHPaneTitleText = "Thanks for contacting us. You have reached us outside of our operating hours. An agent will respond when we open.";
export const OutOfOfficeHoursPaneStateful = props => {
  var _props$styleProps;
  useEffect(() => {
    uiTimer = createTimer();
    TelemetryHelper.logLoadingEventToAllTelemetry(LogLevel.INFO, {
      Event: TelemetryEvent.UXOutOfOfficeHoursPaneStart,
      Description: "Out of office hours pane loading started."
    });
  }, []);
  const [state] = useChatContextStore();
  const generalStyleProps = Object.assign({}, defaultGeneralStyleProps, (_props$styleProps = props.styleProps) === null || _props$styleProps === void 0 ? void 0 : _props$styleProps.generalStyleProps);
  const styleProps = {
    ...props.styleProps,
    generalStyleProps: generalStyleProps
  };
  const controlProps = {
    id: "oc-lcw-outofofficehours-pane",
    dir: state.domainStates.globalDir,
    ...props.controlProps
  };

  // Move focus to the first button
  useEffect(() => {
    if (state.domainStates.widgetElementId !== null && state.domainStates.widgetElementId !== undefined && state.domainStates.widgetElementId.trim() !== "") {
      const firstElement = findAllFocusableElement(`#${state.domainStates.widgetElementId}`);
      if (firstElement && firstElement[0]) {
        firstElement[0].focus();
      }
    }
    TelemetryHelper.logLoadingEvent(LogLevel.INFO, {
      Event: TelemetryEvent.OutOfOfficePaneLoaded
    });
    TelemetryHelper.logLoadingEventToAllTelemetry(LogLevel.INFO, {
      Event: TelemetryEvent.UXOutOfOfficeHoursPaneCompleted,
      Description: "Out of office hours pane loading completed.",
      ElapsedTimeInMilliseconds: uiTimer.milliSecondsElapsed
    });
  }, []);

  // Enhanced titleText sanitization
  if (controlProps !== null && controlProps !== void 0 && controlProps.titleText) {
    const {
      cleanText,
      isXSSDetected
    } = detectAndCleanXSS(controlProps.titleText);
    if (!isXSSDetected) {
      // replace with the sanitized text
      controlProps.titleText = cleanText;
    } else {
      TelemetryHelper.logLoadingEventToAllTelemetry(LogLevel.WARN, {
        Event: TelemetryEvent.XSSTextDetected,
        Description: "Potential XSS attempt detected in titleText",
        CustomProperties: {
          originalText: controlProps.titleText.substring(0, 100),
          // Log first 100 chars for analysis
          cleanedText: cleanText.substring(0, 100)
        }
      });
      controlProps.titleText = OOOHPaneTitleText;
    }
  }
  return /*#__PURE__*/React.createElement(OutOfOfficeHoursPane, {
    componentOverrides: props.componentOverrides,
    controlProps: controlProps,
    styleProps: styleProps
  });
};
export default OutOfOfficeHoursPaneStateful;