/******
 * MaxMessageSizeValidator
 * 
 * Enforces a max character limit that the sender can send to comply to Omnichannel chat services' limitation.
 ******/

import { NotificationHandler } from "../../notification/NotificationHandler";
import { NotificationScenarios } from "../../enums/NotificationScenarios";
import { WebChatActionType } from "../../enums/WebChatActionType";
import { WebChatMiddlewareConstants } from "../../../../../common/Constants";

// eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/no-unused-vars
const createMaxMessageSizeValidator = localizedTexts => _ref => {
  let {
    dispatch
  } = _ref;
  return next => action => {
    if (action.type === WebChatActionType.WEB_CHAT_SET_SEND_BOX) {
      var _action$payload, _action$payload$text;
      const textLength = ((_action$payload = action.payload) === null || _action$payload === void 0 ? void 0 : (_action$payload$text = _action$payload.text) === null || _action$payload$text === void 0 ? void 0 : _action$payload$text.length) || 0;
      if (textLength > WebChatMiddlewareConstants.maxTextLength) {
        NotificationHandler.notifyError(NotificationScenarios.MaxSizeError, localizedTexts.MIDDLEWARE_MAX_CHARACTER_COUNT_EXCEEDED);
        return next(action);
      } else {
        NotificationHandler.dismissNotification(NotificationScenarios.MaxSizeError);
      }
    }
    return next(action);
  };
};
export default createMaxMessageSizeValidator;