function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { HtmlClassNames, HtmlIdNames } from "../../../../common/Constants";
import { NotificationLevel } from "../enums/NotificationLevel";
import { WebChatActionType } from "../enums/WebChatActionType";
import { WebChatStoreLoader } from "../WebChatStoreLoader";
import { setFocusOnSendBox } from "../../../../common/utils";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { BroadcastEvent } from "../../../../common/telemetry/TelemetryConstants";
export let NotificationHandler = /*#__PURE__*/function () {
  function NotificationHandler() {
    _classCallCheck(this, NotificationHandler);
  }
  _createClass(NotificationHandler, null, [{
    key: "notify",
    value: function notify(id, level, message) {
      if (WebChatStoreLoader.store) {
        WebChatStoreLoader.store.dispatch({
          type: WebChatActionType.WEB_CHAT_SET_NOTIFICATION,
          payload: {
            id,
            level,
            message
          }
        });
        NotificationHandler.setFocusOnNotificationCloseButton();
      }
    }
  }, {
    key: "dismissNotification",
    value: function dismissNotification(id) {
      if (WebChatStoreLoader.store) {
        WebChatStoreLoader.store.dispatch({
          type: WebChatActionType.WEB_CHAT_DISMISS_NOTIFICATION,
          payload: {
            id
          }
        });
      }
    }
  }, {
    key: "notifyError",
    value: function notifyError(id, message) {
      BroadcastService.postMessage({
        eventName: BroadcastEvent.OnWidgetError,
        payload: {
          errorMessage: message
        }
      });
      this.notify(id, NotificationLevel.Error, message);
    }
  }, {
    key: "notifyWarning",
    value: function notifyWarning(id, message) {
      this.notify(id, NotificationLevel.Warning, message);
    }
  }, {
    key: "notifyInfo",
    value: function notifyInfo(id, message) {
      this.notify(id, NotificationLevel.Info, message);
    }
  }, {
    key: "notifySuccess",
    value: function notifySuccess(id, message) {
      this.notify(id, NotificationLevel.Success, message);
    }
  }, {
    key: "notifyWithLevel",
    value: function notifyWithLevel(id, message, level) {
      if (!level) {
        this.notifyInfo(id, message);
      } else {
        this.notify(id, level, message);
      }
    }

    /* Bypass WebChat behavior and focus on banner close button */
  }, {
    key: "setFocusOnNotificationCloseButton",
    value: function setFocusOnNotificationCloseButton() {
      const expandButton = document.querySelector(`#${HtmlIdNames.MSLiveChatWidget} .${HtmlClassNames.webChatBannerExpandButton}`);
      if (expandButton) {
        expandButton.focus();
        return;
      }
      const closeButton = document.querySelector(`#${HtmlIdNames.MSLiveChatWidget} .${HtmlClassNames.webChatBannerCloseButton}`);
      if (closeButton) {
        closeButton.focus();
        NotificationHandler.registerOnCloseEvent(closeButton);
        return;
      }
    }
  }, {
    key: "registerOnCloseEvent",
    value: function registerOnCloseEvent(button) {
      button.onclick = () => {
        setFocusOnSendBox();
      };
    }
  }]);
  return NotificationHandler;
}();