function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { BroadcastEvent, LogLevel, TelemetryEvent } from "../common/telemetry/TelemetryConstants";
import { BroadcastService } from "@microsoft/omnichannel-chat-components";
import { TelemetryHelper } from "../common/telemetry/TelemetryHelper";
export let FirstResponseLatencyTracker = /*#__PURE__*/function () {
  function FirstResponseLatencyTracker() {
    _classCallCheck(this, FirstResponseLatencyTracker);
    _defineProperty(this, "isABotConversation", false);
    _defineProperty(this, "isStarted", false);
    _defineProperty(this, "isEnded", false);
    _defineProperty(this, "startTrackingMessage", void 0);
    _defineProperty(this, "stopTrackingMessage", void 0);
    _defineProperty(this, "isReady", false);
    _defineProperty(this, "offlineNetworkListener", BroadcastService.getMessageByEventName(TelemetryEvent.NetworkDisconnected).subscribe(() => {
      this.isStarted = false;
      this.isEnded = false;
      TelemetryHelper.logActionEvent(LogLevel.INFO, {
        Event: TelemetryEvent.MessageStopLapTrackError,
        Description: "Tracker Stopped due to network disconnection"
      });
    }));
    _defineProperty(this, "fmltrackingListener", BroadcastService.getMessageByEventName(BroadcastEvent.FMLTrackingCompleted).subscribe(() => {
      this.isReady = true;
      BroadcastService.postMessage({
        eventName: BroadcastEvent.FMLTrackingCompletedAck,
        payload: null
      });
    }));
    // Rehydrate message is received when the widget is reloaded, this is to ensure that we are not tracking messages that are not part of the current conversation
    // No need to keep listerning for tracking, enforcing disconnection for the listners
    _defineProperty(this, "rehydrateListener", BroadcastService.getMessageByEventName(TelemetryEvent.RehydrateMessageReceived).subscribe(() => {
      this.isReady = true;
    }));
    // Rehydrate message is received when the widget is reloaded, this is to ensure that we are not tracking messages that are not part of the current conversation
    // No need to keep listerning for tracking, enforcing disconnection for the listners
    _defineProperty(this, "historyListener", BroadcastService.getMessageByEventName(BroadcastEvent.HistoryMessageReceived).subscribe(() => {
      this.isReady = true;
    }));
    // this is a workaround to ensure in reload we track effectively the messages
    // we do have a mechanism in place to prevent log agent messages.
    this.isABotConversation = true;
  }
  _createClass(FirstResponseLatencyTracker, [{
    key: "createTrackingMessage",
    value: function createTrackingMessage(payload, type) {
      return {
        Id: payload.Id,
        role: payload.role,
        timestamp: payload === null || payload === void 0 ? void 0 : payload.timestamp,
        tags: payload.tags,
        messageType: payload.messageType,
        text: payload.text,
        type: type,
        checkTime: new Date().getTime()
      };
    }

    // Tracking Functions
  }, {
    key: "startTracking",
    value: function startTracking(payload) {
      if (!this.isReady) return;
      //  this prevents to initiate tracking for multiple incoming messages
      if (this.isStarted) {
        return;
      }
      // this is to ensure we track only messages where bot is engaged
      if (!this.isABotConversation) {
        return;
      }
      // control of states to prevent clashing of messages
      this.isStarted = true;
      this.isEnded = false;
      // The idea  of using types is to enrich telemetry data 
      this.startTrackingMessage = this.createTrackingMessage(payload, "userMessage");
    }
  }, {
    key: "handleAgentMessage",
    value: function handleAgentMessage(payload) {
      var _payload$tags;
      // this tag so far is only present in agent messages
      if (payload !== null && payload !== void 0 && (_payload$tags = payload.tags) !== null && _payload$tags !== void 0 && _payload$tags.includes("public")) {
        this.deregister();
      }
    }
  }, {
    key: "stopTracking",
    value: function stopTracking(payload) {
      var _this$stopTrackingMes, _this$startTrackingMe;
      // this prevents execution for multiple incoming messages from the bot.
      if (this.isEnded && !this.isStarted) {
        return;
      }

      // control of states to prevent clashing of messages
      this.isEnded = true;
      this.isStarted = false;

      // The idea  of using types is to enrich telemetry data 
      this.stopTrackingMessage = this.createTrackingMessage(payload, "botMessage");
      // calculating elapsed time
      const elapsedTime = (((_this$stopTrackingMes = this.stopTrackingMessage) === null || _this$stopTrackingMes === void 0 ? void 0 : _this$stopTrackingMes.checkTime) ?? 0) - (((_this$startTrackingMe = this.startTrackingMessage) === null || _this$startTrackingMe === void 0 ? void 0 : _this$startTrackingMe.checkTime) ?? 0);
      TelemetryHelper.logActionEvent(LogLevel.INFO, {
        Event: TelemetryEvent.MessageLapTrack,
        Description: "First response latency tracking",
        CustomProperties: {
          elapsedTime,
          userMessage: this.startTrackingMessage,
          botMessage: this.stopTrackingMessage
        }
      });
    }

    // mechanism to ensure we track only allowed conversations
  }, {
    key: "isMessageFromValidSender",
    value: function isMessageFromValidSender(payload) {
      var _payload$tags2;
      // agent scenario
      if (payload !== null && payload !== void 0 && (_payload$tags2 = payload.tags) !== null && _payload$tags2 !== void 0 && _payload$tags2.includes("public")) {
        this.handleAgentMessage(payload);
        return false;
      }
      return true;
    }
  }, {
    key: "startClock",
    value: function startClock(payload) {
      try {
        if (!payload || !payload.Id) {
          throw new Error("Invalid payload");
        }
        this.startTracking(payload);
      } catch (e) {
        TelemetryHelper.logActionEvent(LogLevel.ERROR, {
          Event: TelemetryEvent.MessageStartLapTrackError,
          Description: "Error while starting the clock",
          ExceptionDetails: e,
          CustomProperties: {
            payload: payload
          }
        });
      }
    }
  }, {
    key: "stopClock",
    value: function stopClock(payload) {
      try {
        if (!payload || !payload.Id) {
          throw new Error("Invalid payload");
        }
        if (!this.isMessageFromValidSender(payload)) return;
        if (this.isABotConversation && this.isStarted) {
          this.stopTracking(payload);
        }
      } catch (e) {
        console.error("FRL : error while trying to stop the tracker", e);
        TelemetryHelper.logActionEvent(LogLevel.ERROR, {
          Event: TelemetryEvent.MessageStopLapTrackError,
          Description: "Error while stopping the clock",
          ExceptionDetails: e,
          CustomProperties: {
            payload: payload
          }
        });
        //reset state
        this.startTrackingMessage = undefined;
        this.stopTrackingMessage = undefined;
        this.isStarted = false;
        this.isEnded = false;
      }
    }
  }, {
    key: "deregister",
    value: function deregister() {
      // Reset State
      this.isABotConversation = false;
      this.isStarted = false;
      this.isEnded = false;
      this.startTrackingMessage = undefined;
      this.stopTrackingMessage = undefined;
      this.offlineNetworkListener.unsubscribe();
      this.fmltrackingListener.unsubscribe();
      this.rehydrateListener.unsubscribe();
      this.historyListener.unsubscribe();
    }
  }]);
  return FirstResponseLatencyTracker;
}();