/**
 * Detects potential Cross-Site Scripting (XSS) attacks in text input and sanitizes the content.
 *
 * This function performs comprehensive XSS detection using pattern matching for common attack vectors
 * and then sanitizes the input using DOMPurify with strict configuration. It's designed to protect
 * against various XSS techniques including script injection, event handler injection, style-based
 * attacks, and encoded payloads.
 *
 * Security patterns detected:
 * - JavaScript protocol URLs (javascript:)
 * - HTML event handlers (onmouseover, onclick, etc.)
 * - Script tags (<script>)
 * - CSS expression() functions
 * - CSS url() functions
 * - Position-based CSS attacks (position: fixed/absolute)
 * - VBScript protocol URLs
 * - Data URLs with HTML content
 * - Fragment identifiers with escaped quotes
 * - HTML entity-encoded angle brackets
 *
 * @param text - The input text to be analyzed and sanitized
 * @returns An object containing:
 *   - cleanText: The sanitized version of the input text with all HTML tags and attributes removed
 *   - isXSSDetected: Boolean flag indicating whether potential XSS patterns were found in the original text
 */
export declare const detectAndCleanXSS: (text: string) => {
    cleanText: string;
    isXSSDetected: boolean;
};
